/* GomElement.c generated by valac 0.34.6, the Vala compiler
 * generated from GomElement.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;
typedef struct _GXmlGomNodePrivate GXmlGomNodePrivate;

#define GXML_TYPE_GOM_NODE_LIST (gxml_gom_node_list_get_type ())
#define GXML_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList))
#define GXML_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))
#define GXML_IS_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE_LIST))
#define GXML_IS_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE_LIST))
#define GXML_GOM_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))

typedef struct _GXmlGomNodeList GXmlGomNodeList;
typedef struct _GXmlGomNodeListClass GXmlGomNodeListClass;

#define GXML_TYPE_GOM_OBJECT (gxml_gom_object_get_type ())
#define GXML_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObject))
#define GXML_IS_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_OBJECT))
#define GXML_GOM_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObjectIface))

typedef struct _GXmlGomObject GXmlGomObject;
typedef struct _GXmlGomObjectIface GXmlGomObjectIface;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;
typedef struct _GXmlGomElementPrivate GXmlGomElementPrivate;

#define GXML_GOM_ELEMENT_TYPE_ATTRIBUTES (gxml_gom_element_attributes_get_type ())
#define GXML_GOM_ELEMENT_ATTRIBUTES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributes))
#define GXML_GOM_ELEMENT_ATTRIBUTES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributesClass))
#define GXML_GOM_ELEMENT_IS_ATTRIBUTES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES))
#define GXML_GOM_ELEMENT_IS_ATTRIBUTES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES))
#define GXML_GOM_ELEMENT_ATTRIBUTES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributesClass))

typedef struct _GXmlGomElementAttributes GXmlGomElementAttributes;
typedef struct _GXmlGomElementAttributesClass GXmlGomElementAttributesClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_XPARSER (gxml_xparser_get_type ())
#define GXML_XPARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPARSER, GXmlXParser))
#define GXML_XPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_XPARSER, GXmlXParserClass))
#define GXML_IS_XPARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPARSER))
#define GXML_IS_XPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_XPARSER))
#define GXML_XPARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_XPARSER, GXmlXParserClass))

typedef struct _GXmlXParser GXmlXParser;
typedef struct _GXmlXParserClass GXmlXParserClass;

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_GOM_DOCUMENT (gxml_gom_document_get_type ())
#define GXML_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument))
#define GXML_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))
#define GXML_IS_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOCUMENT))
#define GXML_IS_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOCUMENT))
#define GXML_GOM_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))

typedef struct _GXmlGomDocument GXmlGomDocument;
typedef struct _GXmlGomDocumentClass GXmlGomDocumentClass;

#define GXML_TYPE_GOM_ATTR (gxml_gom_attr_get_type ())
#define GXML_GOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ATTR, GXmlGomAttr))
#define GXML_GOM_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ATTR, GXmlGomAttrClass))
#define GXML_IS_GOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ATTR))
#define GXML_IS_GOM_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ATTR))
#define GXML_GOM_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ATTR, GXmlGomAttrClass))

typedef struct _GXmlGomAttr GXmlGomAttr;
typedef struct _GXmlGomAttrClass GXmlGomAttrClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GXML_TYPE_GDOM_HTML_COLLECTION (gxml_gdom_html_collection_get_type ())
#define GXML_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollection))
#define GXML_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))
#define GXML_IS_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_IS_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_GDOM_HTML_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))

typedef struct _GXmlGDomHTMLCollection GXmlGDomHTMLCollection;
typedef struct _GXmlGDomHTMLCollectionClass GXmlGDomHTMLCollectionClass;

#define GXML_TYPE_GDOM_TOKEN_LIST (gxml_gdom_token_list_get_type ())
#define GXML_GDOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenList))
#define GXML_GDOM_TOKEN_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenListClass))
#define GXML_IS_GDOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_TOKEN_LIST))
#define GXML_IS_GDOM_TOKEN_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_TOKEN_LIST))
#define GXML_GDOM_TOKEN_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenListClass))

typedef struct _GXmlGDomTokenList GXmlGDomTokenList;
typedef struct _GXmlGDomTokenListClass GXmlGDomTokenListClass;
typedef struct _GXmlGomElementAttributesPrivate GXmlGomElementAttributesPrivate;

#define GXML_TYPE_DOM_ATTR (gxml_dom_attr_get_type ())
#define GXML_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttr))
#define GXML_IS_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ATTR))
#define GXML_DOM_ATTR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttrIface))

typedef struct _GXmlDomAttr GXmlDomAttr;
typedef struct _GXmlDomAttrIface GXmlDomAttrIface;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGomNode {
	GObject parent_instance;
	GXmlGomNodePrivate * priv;
	gchar* _local_name;
	gchar* _prefix;
	gchar* _base_uri;
	gchar* _node_value;
	GXmlDomNode* _parent;
	GXmlDomNodeNodeType _node_type;
	GXmlGomNodeList* _child_nodes;
	GXmlDomDocument* _document;
};

struct _GXmlGomNodeClass {
	GObjectClass parent_class;
};

struct _GXmlGomObjectIface {
	GTypeInterface parent_iface;
	GList* (*get_properties_list) (GXmlGomObject* self);
	GParamSpec* (*find_property_name) (GXmlGomObject* self, const gchar* pname);
	GParamSpec* (*find_object_property_name) (GXmlGomObject* self, const gchar* pname);
	GList* (*get_property_element_list) (GXmlGomObject* self);
	gchar* (*get_property_string) (GXmlGomObject* self, GParamSpec* prop);
	gchar* (*get_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_attribute) (GXmlGomObject* self, const gchar* name, const gchar* val);
	GXmlDomElement* (*get_child) (GXmlGomObject* self, const gchar* name);
	GXmlDomElementList* (*find_elements) (GXmlGomObject* self, const gchar* name);
	gboolean (*remove_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_instance_property) (GXmlGomObject* self, const gchar* name);
	void (*clean_property_elements) (GXmlGomObject* self, const gchar* name, GError** error);
};

struct _GXmlGomElement {
	GXmlGomNode parent_instance;
	GXmlGomElementPrivate * priv;
	GXmlGomElementAttributes* _attributes;
	gchar* _namespace_uri;
};

struct _GXmlGomElementClass {
	GXmlGomNodeClass parent_class;
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GCancellable* cancellable, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlGomElementAttributes {
	GeeHashMap parent_instance;
	GXmlGomElementAttributesPrivate * priv;
	GXmlGomElement* _element;
};

struct _GXmlGomElementAttributesClass {
	GeeHashMapClass parent_class;
};

struct _GXmlDomAttrIface {
	GTypeInterface parent_iface;
	gchar* (*get_namespace_uri) (GXmlDomAttr* self);
	gchar* (*get_prefix) (GXmlDomAttr* self);
	gchar* (*get_local_name) (GXmlDomAttr* self);
	gchar* (*get_name) (GXmlDomAttr* self);
	gchar* (*get_value) (GXmlDomAttr* self);
	void (*set_value) (GXmlDomAttr* self, const gchar* value);
	gboolean (*get_specified) (GXmlDomAttr* self);
};


static gpointer gxml_gom_element_parent_class = NULL;
static gpointer gxml_gom_element_attributes_parent_class = NULL;
static GXmlDomNamedNodeMapIface* gxml_gom_element_attributes_gxml_dom_named_node_map_parent_iface = NULL;
static GXmlDomChildNodeIface* gxml_gom_element_gxml_dom_child_node_parent_iface = NULL;
static GXmlDomNonDocumentTypeChildNodeIface* gxml_gom_element_gxml_dom_non_document_type_child_node_parent_iface = NULL;
static GXmlDomParentNodeIface* gxml_gom_element_gxml_dom_parent_node_parent_iface = NULL;
static GXmlDomElementIface* gxml_gom_element_gxml_dom_element_parent_iface = NULL;
static GXmlGomObjectIface* gxml_gom_element_gxml_gom_object_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_gom_object_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_attributes_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_ELEMENT_DUMMY_PROPERTY,
	GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING,
	GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING,
	GXML_GOM_ELEMENT_CHILDREN,
	GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD,
	GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD,
	GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT,
	GXML_GOM_ELEMENT_NAMESPACE_URI,
	GXML_GOM_ELEMENT_PREFIX,
	GXML_GOM_ELEMENT_LOCAL_NAME,
	GXML_GOM_ELEMENT_TAG_NAME,
	GXML_GOM_ELEMENT_ID,
	GXML_GOM_ELEMENT_CLASS_NAME,
	GXML_GOM_ELEMENT_CLASS_LIST,
	GXML_GOM_ELEMENT_ATTRIBUTES
};
void gxml_gom_element_read_from_uri (GXmlGomElement* self, const gchar* uri, GError** error);
void gxml_gom_element_read_from_file (GXmlGomElement* self, GFile* f, GCancellable* cancellable, GError** error);
GType gxml_xparser_get_type (void) G_GNUC_CONST;
GXmlXParser* gxml_xparser_new (GXmlDomNode* node);
GXmlXParser* gxml_xparser_construct (GType object_type, GXmlDomNode* node);
GType gxml_parser_get_type (void) G_GNUC_CONST;
void gxml_parser_read_file (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
void gxml_gom_element_read_from_stream (GXmlGomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error);
void gxml_parser_read_stream (GXmlParser* self, GInputStream* stream, GCancellable* cancellable, GError** error);
void gxml_gom_element_read_from_string (GXmlGomElement* self, const gchar* str, GError** error);
void gxml_parser_read_string (GXmlParser* self, const gchar* str, GCancellable* cancellable, GError** error);
gchar* gxml_gom_element_write_string (GXmlGomElement* self, GError** error);
gchar* gxml_parser_write_string (GXmlParser* self, GError** error);
void gxml_gom_element_write_file (GXmlGomElement* self, GFile* f, GError** error);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GType gxml_gom_document_get_type (void) G_GNUC_CONST;
void gxml_gom_document_write_file (GXmlGomDocument* self, GFile* file, GError** error);
void gxml_gom_element_write_stream (GXmlGomElement* self, GOutputStream* stream, GError** error);
void gxml_gom_document_write_stream (GXmlGomDocument* self, GOutputStream* stream, GError** error);
gchar* gxml_gom_element_lookup_prefix (GXmlGomElement* self, const gchar* nspace);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
gchar* gxml_dom_node_lookup_prefix (GXmlDomNode* self, const gchar* nspace);
gchar* gxml_gom_element_lookup_namespace_uri (GXmlGomElement* self, const gchar* prefix);
gchar* gxml_dom_element_get_namespace_uri (GXmlDomElement* self);
GXmlDomNamedNodeMap* gxml_dom_element_get_attributes (GXmlDomElement* self);
gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self, const gchar* prefix);
static void gxml_gom_element_real_remove (GXmlDomChildNode* base);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
static GXmlDomElement* gxml_gom_element_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error);
GQuark gxml_dom_error_quark (void);
static GXmlDomNodeList* gxml_gom_element_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error);
void gxml_gom_element_initialize (GXmlGomElement* self, const gchar* local_name);
void gxml_gom_element_initialize_document (GXmlGomElement* self, GXmlDomDocument* doc, const gchar* local_name);
void gxml_gom_element_initialize_with_namespace (GXmlGomElement* self, const gchar* namespace_uri, const gchar* prefix, const gchar* local_name);
void gxml_gom_element_initialize_document_with_namespace (GXmlGomElement* self, GXmlDomDocument* doc, const gchar* namespace_uri, const gchar* prefix, const gchar* local_name);
static gchar* gxml_gom_element_real_get_attribute (GXmlDomElement* base, const gchar* name);
gchar* gxml_gom_object_get_attribute (GXmlGomObject* self, const gchar* name);
static gchar* gxml_gom_element_real_get_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* local_name);
static void gxml_gom_element_real_set_attribute (GXmlDomElement* base, const gchar* name, const gchar* value, GError** error);
gboolean gxml_gom_object_set_attribute (GXmlGomObject* self, const gchar* name, const gchar* val);
GType gxml_gom_attr_get_type (void) G_GNUC_CONST;
GXmlGomAttr* gxml_gom_attr_new (GXmlDomElement* element, const gchar* name, const gchar* value);
GXmlGomAttr* gxml_gom_attr_construct (GType object_type, GXmlDomElement* element, const gchar* name, const gchar* value);
GXmlDomNode* gxml_dom_named_node_map_set_named_item (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
static void gxml_gom_element_real_set_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* name, const gchar* value, GError** error);
GXmlGomAttr* gxml_gom_attr_new_namespace (GXmlDomElement* element, const gchar* namespace_uri, const gchar* prefix, const gchar* name, const gchar* value);
GXmlGomAttr* gxml_gom_attr_construct_namespace (GType object_type, GXmlDomElement* element, const gchar* namespace_uri, const gchar* prefix, const gchar* name, const gchar* value);
GXmlDomNode* gxml_dom_named_node_map_set_named_item_ns (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
static void gxml_gom_element_real_remove_attribute (GXmlDomElement* base, const gchar* name);
gboolean gxml_gom_object_remove_attribute (GXmlGomObject* self, const gchar* name);
GXmlDomNode* gxml_dom_named_node_map_remove_named_item (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
static void gxml_gom_element_real_remove_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* local_name);
GXmlDomNode* gxml_dom_named_node_map_remove_named_item_ns (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
static gboolean gxml_gom_element_real_has_attribute (GXmlDomElement* base, const gchar* name);
static gboolean gxml_gom_element_real_has_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_tag_name (GXmlDomElement* base, const gchar* local_name);
GType gxml_gdom_html_collection_get_type (void) G_GNUC_CONST;
GXmlGDomHTMLCollection* gxml_gdom_html_collection_new (void);
GXmlGDomHTMLCollection* gxml_gdom_html_collection_construct (GType object_type);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name (GXmlDomElement* self, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_tag_name_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name_ns (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_class_name (GXmlDomElement* base, const gchar* class_names);
static void _vala_array_add8 (gchar*** array, int* length, int* size, gchar* value);
gchar* gxml_dom_element_get_attribute (GXmlDomElement* self, const gchar* name);
static void _vala_array_add9 (gchar*** array, int* length, int* size, gchar* value);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_class_name (GXmlDomElement* self, const gchar* class_names);
GXmlGomElement* gxml_gom_element_new (void);
GXmlGomElement* gxml_gom_element_construct (GType object_type);
GXmlGomNode* gxml_gom_node_new (void);
GXmlGomNode* gxml_gom_node_construct (GType object_type);
GXmlDomNode* gxml_dom_node_list_item (GXmlDomNodeList* self, gint index);
gint gxml_dom_node_list_get_length (GXmlDomNodeList* self);
GXmlDomElementList* gxml_dom_element_list_new (void);
GXmlDomElementList* gxml_dom_element_list_construct (GType object_type);
GXmlDomHTMLCollection* gxml_dom_parent_node_get_children (GXmlDomParentNode* self);
GXmlGDomTokenList* gxml_gdom_token_list_new (GXmlDomElement* e, const gchar* attr);
GXmlGDomTokenList* gxml_gdom_token_list_construct (GType object_type, GXmlDomElement* e, const gchar* attr);
GType gxml_gdom_token_list_get_type (void) G_GNUC_CONST;
static GObject * gxml_gom_element_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GXmlGomElementAttributes* gxml_gom_element_attributes_new (GXmlGomElement* element);
GXmlGomElementAttributes* gxml_gom_element_attributes_construct (GType object_type, GXmlGomElement* element);
enum  {
	GXML_GOM_ELEMENT_ATTRIBUTES_DUMMY_PROPERTY,
	GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH
};
static GXmlDomNode* gxml_gom_element_attributes_real_item (GXmlDomNamedNodeMap* base, gint index);
static GXmlDomNode* gxml_gom_element_attributes_real_get_named_item (GXmlDomNamedNodeMap* base, const gchar* name);
static GXmlDomNode* gxml_gom_element_attributes_real_set_named_item (GXmlDomNamedNodeMap* base, GXmlDomNode* node, GError** error);
GType gxml_dom_attr_get_type (void) G_GNUC_CONST;
gchar* gxml_dom_attr_get_local_name (GXmlDomAttr* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
static GXmlDomNode* gxml_gom_element_attributes_real_remove_named_item (GXmlDomNamedNodeMap* base, const gchar* name, GError** error);
static GXmlDomNode* gxml_gom_element_attributes_real_remove_named_item_ns (GXmlDomNamedNodeMap* base, const gchar* namespace_uri, const gchar* local_name, GError** error);
static GXmlDomNode* gxml_gom_element_attributes_real_get_named_item_ns (GXmlDomNamedNodeMap* base, const gchar* namespace_uri, const gchar* local_name, GError** error);
static GXmlDomNode* gxml_gom_element_attributes_real_set_named_item_ns (GXmlDomNamedNodeMap* base, GXmlDomNode* node, GError** error);
gchar* gxml_dom_attr_get_prefix (GXmlDomAttr* self);
gchar* gxml_dom_attr_get_namespace_uri (GXmlDomAttr* self);
gchar* gxml_dom_element_get_attribute_ns (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
static void gxml_gom_element_attributes_finalize (GObject* obj);
gint gxml_dom_named_node_map_get_length (GXmlDomNamedNodeMap* self);
static void _vala_gxml_gom_element_attributes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void gxml_gom_element_finalize (GObject* obj);
GXmlDomElement* gxml_dom_non_document_type_child_node_get_previous_element_sibling (GXmlDomNonDocumentTypeChildNode* self);
GXmlDomElement* gxml_dom_non_document_type_child_node_get_next_element_sibling (GXmlDomNonDocumentTypeChildNode* self);
GXmlDomElement* gxml_dom_parent_node_get_first_element_child (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_last_element_child (GXmlDomParentNode* self);
gint gxml_dom_parent_node_get_child_element_count (GXmlDomParentNode* self);
gchar* gxml_dom_element_get_prefix (GXmlDomElement* self);
gchar* gxml_dom_element_get_local_name (GXmlDomElement* self);
gchar* gxml_dom_element_get_tag_name (GXmlDomElement* self);
gchar* gxml_dom_element_get_id (GXmlDomElement* self);
gchar* gxml_dom_element_get_class_name (GXmlDomElement* self);
GXmlDomTokenList* gxml_dom_element_get_class_list (GXmlDomElement* self);
static void _vala_gxml_gom_element_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void gxml_dom_element_set_id (GXmlDomElement* self, const gchar* value);
void gxml_dom_element_set_class_name (GXmlDomElement* self, const gchar* value);
static void _vala_gxml_gom_element_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


/**
   * Parsing a URI file.
   */
void gxml_gom_element_read_from_uri (GXmlGomElement* self, const gchar* uri, GError** error) {
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (uri != NULL);
	_tmp0_ = uri;
	_tmp1_ = g_file_new_for_uri (_tmp0_);
	_tmp2_ = _tmp1_;
	gxml_gom_element_read_from_file (self, _tmp2_, NULL, &_inner_error_);
	_g_object_unref0 (_tmp2_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
}


/**
   * Parses an XML file, deserializing it over {@link GomElement}.
   */
void gxml_gom_element_read_from_file (GXmlGomElement* self, GFile* f, GCancellable* cancellable, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (f != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = f;
	_tmp2_ = cancellable;
	gxml_parser_read_file ((GXmlParser*) parser, _tmp1_, _tmp2_, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


/**
   * Parses an XML over a {@link GLib.InputStream}, deserializing it over {@link GomElement}.
   */
void gxml_gom_element_read_from_stream (GXmlGomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GInputStream* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (istream != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = istream;
	_tmp2_ = cancellable;
	gxml_parser_read_stream ((GXmlParser*) parser, _tmp1_, _tmp2_, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


/**
   * Parses an XML string, deserializing it over {@link GomElement}.
   */
void gxml_gom_element_read_from_string (GXmlGomElement* self, const gchar* str, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (str != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = str;
	gxml_parser_read_string ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


/**
   * Serialize {@link GomElement} to a string.
   */
gchar* gxml_gom_element_write_string (GXmlGomElement* self, GError** error) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp2_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
	_tmp1_ = _tmp2_;
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return NULL;
	}
	_tmp3_ = _tmp1_;
	_tmp1_ = NULL;
	result = _tmp3_;
	_g_free0 (_tmp1_);
	_g_object_unref0 (parser);
	return result;
}


/**
   * Uses element's {@link GomDocument} to write an XML to a file, serializing it.
   */
void gxml_gom_element_write_file (GXmlGomElement* self, GFile* f, GError** error) {
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (f != NULL);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = f;
	gxml_gom_document_write_file (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp1_) : NULL, _tmp2_, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
}


/**
   * Uses element's {@link GomDocument} to write an XML to a stream, serializing it.
   */
void gxml_gom_element_write_stream (GXmlGomElement* self, GOutputStream* stream, GError** error) {
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	GOutputStream* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (stream != NULL);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = stream;
	gxml_gom_document_write_stream (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp1_) : NULL, _tmp2_, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = needle;
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
	result = _tmp1_ != NULL;
	return result;
}


gchar* gxml_gom_element_lookup_prefix (GXmlGomElement* self, const gchar* nspace) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GXmlDomNode* _tmp33_ = NULL;
	GXmlDomNode* _tmp34_ = NULL;
	GXmlDomNode* _tmp35_ = NULL;
	gboolean _tmp36_ = FALSE;
	GXmlDomNode* _tmp37_ = NULL;
	GXmlDomNode* _tmp38_ = NULL;
	GXmlDomNode* _tmp39_ = NULL;
	const gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_namespace_uri;
	_tmp1_ = nspace;
	if (g_strcmp0 (_tmp0_, _tmp1_) == 0) {
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		_tmp2_ = ((GXmlGomNode*) self)->_prefix;
		_tmp3_ = g_strdup (_tmp2_);
		result = _tmp3_;
		return result;
	}
	{
		GeeIterator* _k_it = NULL;
		GXmlGomElementAttributes* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeSet* _tmp6_ = NULL;
		GeeSet* _tmp7_ = NULL;
		GeeIterator* _tmp8_ = NULL;
		GeeIterator* _tmp9_ = NULL;
		_tmp4_ = self->_attributes;
		_tmp5_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = _tmp6_;
		_tmp8_ = gee_iterable_iterator ((GeeIterable*) _tmp7_);
		_tmp9_ = _tmp8_;
		_g_object_unref0 (_tmp7_);
		_k_it = _tmp9_;
		while (TRUE) {
			GeeIterator* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			gchar* k = NULL;
			GeeIterator* _tmp12_ = NULL;
			gpointer _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			gboolean _tmp15_ = FALSE;
			gchar* ns_uri = NULL;
			GXmlGomElementAttributes* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			gpointer _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			_tmp10_ = _k_it;
			_tmp11_ = gee_iterator_next (_tmp10_);
			if (!_tmp11_) {
				break;
			}
			_tmp12_ = _k_it;
			_tmp13_ = gee_iterator_get (_tmp12_);
			k = (gchar*) _tmp13_;
			_tmp14_ = k;
			_tmp15_ = string_contains (_tmp14_, "xmlns");
			if (!_tmp15_) {
				_g_free0 (k);
				continue;
			}
			_tmp16_ = self->_attributes;
			_tmp17_ = k;
			_tmp18_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp16_, _tmp17_);
			ns_uri = (gchar*) _tmp18_;
			_tmp19_ = ns_uri;
			if (_tmp19_ == NULL) {
				const gchar* _tmp20_ = NULL;
				_tmp20_ = _ ("Invalid namespace URI stored in element's attribute");
				g_warning ("GomElement.vala:97: %s", _tmp20_);
				result = NULL;
				_g_free0 (ns_uri);
				_g_free0 (k);
				_g_object_unref0 (_k_it);
				return result;
			}
			_tmp21_ = ns_uri;
			_tmp22_ = nspace;
			if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
				const gchar* _tmp23_ = NULL;
				gboolean _tmp24_ = FALSE;
				_tmp23_ = k;
				_tmp24_ = string_contains (_tmp23_, ":");
				if (_tmp24_) {
					gchar** sa = NULL;
					const gchar* _tmp25_ = NULL;
					gchar** _tmp26_ = NULL;
					gchar** _tmp27_ = NULL;
					gint sa_length1 = 0;
					gint _sa_size_ = 0;
					gchar** _tmp28_ = NULL;
					gint _tmp28__length1 = 0;
					gchar** _tmp30_ = NULL;
					gint _tmp30__length1 = 0;
					const gchar* _tmp31_ = NULL;
					gchar* _tmp32_ = NULL;
					_tmp25_ = k;
					_tmp27_ = _tmp26_ = g_strsplit (_tmp25_, ":", 0);
					sa = _tmp27_;
					sa_length1 = _vala_array_length (_tmp26_);
					_sa_size_ = sa_length1;
					_tmp28_ = sa;
					_tmp28__length1 = sa_length1;
					if (_tmp28__length1 > 2) {
						const gchar* _tmp29_ = NULL;
						_tmp29_ = _ ("Invalid attribute name in element's attributes list");
						g_warning ("GomElement.vala:104: %s", _tmp29_);
						result = NULL;
						sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
						_g_free0 (ns_uri);
						_g_free0 (k);
						_g_object_unref0 (_k_it);
						return result;
					}
					_tmp30_ = sa;
					_tmp30__length1 = sa_length1;
					_tmp31_ = _tmp30_[1];
					_tmp32_ = g_strdup (_tmp31_);
					result = _tmp32_;
					sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
					_g_free0 (ns_uri);
					_g_free0 (k);
					_g_object_unref0 (_k_it);
					return result;
				}
			}
			_g_free0 (ns_uri);
			_g_free0 (k);
		}
		_g_object_unref0 (_k_it);
	}
	_tmp33_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp34_ = _tmp33_;
	_tmp35_ = _tmp34_;
	_tmp36_ = _tmp35_ == NULL;
	_g_object_unref0 (_tmp35_);
	if (_tmp36_) {
		result = NULL;
		return result;
	}
	_tmp37_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp38_ = _tmp37_;
	_tmp39_ = _tmp38_;
	_tmp40_ = nspace;
	_tmp41_ = gxml_dom_node_lookup_prefix (_tmp39_, _tmp40_);
	_tmp42_ = _tmp41_;
	_g_object_unref0 (_tmp39_);
	result = _tmp42_;
	return result;
}


gchar* gxml_gom_element_lookup_namespace_uri (GXmlGomElement* self, const gchar* prefix) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gchar* s = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GXmlDomNode* _tmp39_ = NULL;
	GXmlDomNode* _tmp40_ = NULL;
	GXmlDomNode* _tmp41_ = NULL;
	gboolean _tmp42_ = FALSE;
	GXmlDomNode* _tmp43_ = NULL;
	GXmlDomNode* _tmp44_ = NULL;
	GXmlDomNode* _tmp45_ = NULL;
	const gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp1_ = self->_namespace_uri;
	if (_tmp1_ != NULL) {
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		_tmp2_ = ((GXmlGomNode*) self)->_prefix;
		_tmp3_ = prefix;
		_tmp0_ = g_strcmp0 (_tmp2_, _tmp3_) == 0;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		_tmp4_ = gxml_dom_element_get_namespace_uri ((GXmlDomElement*) self);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		return result;
	}
	_tmp6_ = g_strdup ("");
	s = _tmp6_;
	_tmp7_ = prefix;
	if (_tmp7_ != NULL) {
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		_tmp8_ = prefix;
		_tmp9_ = g_strdup (_tmp8_);
		_g_free0 (s);
		s = _tmp9_;
	}
	{
		GeeIterator* _k_it = NULL;
		GXmlDomNamedNodeMap* _tmp10_ = NULL;
		GXmlDomNamedNodeMap* _tmp11_ = NULL;
		GXmlDomNamedNodeMap* _tmp12_ = NULL;
		GeeSet* _tmp13_ = NULL;
		GeeSet* _tmp14_ = NULL;
		GeeSet* _tmp15_ = NULL;
		GeeIterator* _tmp16_ = NULL;
		GeeIterator* _tmp17_ = NULL;
		_tmp10_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
		_tmp11_ = _tmp10_;
		_tmp12_ = _tmp11_;
		_tmp13_ = gee_map_get_keys ((GeeMap*) _tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = gee_iterable_iterator ((GeeIterable*) _tmp15_);
		_tmp17_ = _tmp16_;
		_g_object_unref0 (_tmp15_);
		_g_object_unref0 (_tmp12_);
		_k_it = _tmp17_;
		while (TRUE) {
			GeeIterator* _tmp18_ = NULL;
			gboolean _tmp19_ = FALSE;
			gchar* k = NULL;
			GeeIterator* _tmp20_ = NULL;
			gpointer _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			gchar* nsp = NULL;
			const gchar* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			const gchar* _tmp34_ = NULL;
			const gchar* _tmp35_ = NULL;
			GXmlGomElementAttributes* _tmp36_ = NULL;
			const gchar* _tmp37_ = NULL;
			gpointer _tmp38_ = NULL;
			_tmp18_ = _k_it;
			_tmp19_ = gee_iterator_next (_tmp18_);
			if (!_tmp19_) {
				break;
			}
			_tmp20_ = _k_it;
			_tmp21_ = gee_iterator_get (_tmp20_);
			k = (gchar*) _tmp21_;
			_tmp22_ = k;
			_tmp23_ = string_contains (_tmp22_, "xmlns");
			if (!_tmp23_) {
				_g_free0 (k);
				continue;
			}
			nsp = NULL;
			_tmp24_ = k;
			_tmp25_ = string_contains (_tmp24_, ":");
			if (_tmp25_) {
				gchar** sa = NULL;
				const gchar* _tmp26_ = NULL;
				gchar** _tmp27_ = NULL;
				gchar** _tmp28_ = NULL;
				gint sa_length1 = 0;
				gint _sa_size_ = 0;
				gchar** _tmp29_ = NULL;
				gint _tmp29__length1 = 0;
				gchar** _tmp31_ = NULL;
				gint _tmp31__length1 = 0;
				const gchar* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				_tmp26_ = k;
				_tmp28_ = _tmp27_ = g_strsplit (_tmp26_, ":", 0);
				sa = _tmp28_;
				sa_length1 = _vala_array_length (_tmp27_);
				_sa_size_ = sa_length1;
				_tmp29_ = sa;
				_tmp29__length1 = sa_length1;
				if (_tmp29__length1 > 2) {
					const gchar* _tmp30_ = NULL;
					_tmp30_ = _ ("Invalid attribute name in element's attributes list");
					g_warning ("GomElement.vala:128: %s", _tmp30_);
					result = NULL;
					sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
					_g_free0 (nsp);
					_g_free0 (k);
					_g_object_unref0 (_k_it);
					_g_free0 (s);
					return result;
				}
				_tmp31_ = sa;
				_tmp31__length1 = sa_length1;
				_tmp32_ = _tmp31_[1];
				_tmp33_ = g_strdup (_tmp32_);
				_g_free0 (nsp);
				nsp = _tmp33_;
				sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
			}
			_tmp34_ = nsp;
			_tmp35_ = prefix;
			if (g_strcmp0 (_tmp34_, _tmp35_) != 0) {
				_g_free0 (nsp);
				_g_free0 (k);
				continue;
			}
			_tmp36_ = self->_attributes;
			_tmp37_ = k;
			_tmp38_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp36_, _tmp37_);
			result = (gchar*) _tmp38_;
			_g_free0 (nsp);
			_g_free0 (k);
			_g_object_unref0 (_k_it);
			_g_free0 (s);
			return result;
		}
		_g_object_unref0 (_k_it);
	}
	_tmp39_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp40_ = _tmp39_;
	_tmp41_ = _tmp40_;
	_tmp42_ = _tmp41_ == NULL;
	_g_object_unref0 (_tmp41_);
	if (_tmp42_) {
		result = NULL;
		_g_free0 (s);
		return result;
	}
	_tmp43_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp44_ = _tmp43_;
	_tmp45_ = _tmp44_;
	_tmp46_ = prefix;
	_tmp47_ = gxml_dom_node_lookup_namespace_uri (_tmp45_, _tmp46_);
	_tmp48_ = _tmp47_;
	_g_object_unref0 (_tmp45_);
	result = _tmp48_;
	_g_free0 (s);
	return result;
}


static void gxml_gom_element_real_remove (GXmlDomChildNode* base) {
	GXmlGomElement * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ != NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		gint i = 0;
		GXmlDomNode* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlDomNodeList* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		gint _tmp11_ = 0;
		GXmlDomNode* _tmp12_ = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		gpointer _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gee_list_index_of ((GeeList*) _tmp9_, (GXmlDomNode*) self);
		_tmp11_ = _tmp10_;
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (_tmp6_);
		i = _tmp11_;
		_tmp12_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp13_ = _tmp12_;
		_tmp14_ = _tmp13_;
		_tmp15_ = gxml_dom_node_get_child_nodes (_tmp14_);
		_tmp16_ = _tmp15_;
		_tmp17_ = _tmp16_;
		_tmp18_ = i;
		_tmp19_ = gee_list_remove_at ((GeeList*) _tmp17_, _tmp18_);
		_tmp20_ = (GXmlDomNode*) _tmp19_;
		_g_object_unref0 (_tmp20_);
		_g_object_unref0 (_tmp17_);
		_g_object_unref0 (_tmp14_);
	}
}


static GXmlDomElement* gxml_gom_element_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGomElement * self;
	GXmlDomElement* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = _ ("DomElement query_selector is not implemented");
	_tmp1_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_SYNTAX_ERROR, _tmp0_);
	_inner_error_ = _tmp1_;
	g_propagate_error (error, _inner_error_);
	return NULL;
	return result;
}


static GXmlDomNodeList* gxml_gom_element_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGomElement * self;
	GXmlDomNodeList* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = _ ("DomElement query_selector_all is not implemented");
	_tmp1_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_SYNTAX_ERROR, _tmp0_);
	_inner_error_ = _tmp1_;
	g_propagate_error (error, _inner_error_);
	return NULL;
	return result;
}


/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name. If {@link GomElement.initialize_with_namespace}
   * has been called in any base class, this method just change elment node's name
   * and keeps previous namespace and prefix.
   *
   * No {@link DomDocument} is set by default, if this is a top level element in a
   * document, you can call {@link DomNode.owner_document} to set one if not set
   * already.
   *
   * Any instance properties of type {@link GomElement} or {@link GomCollection}
   * should be initialized using {@link GomObject.set_instance_property}
   */
void gxml_gom_element_initialize (GXmlGomElement* self, const gchar* local_name) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = local_name;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp1_;
}


/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name and document.
   */
static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


void gxml_gom_element_initialize_document (GXmlGomElement* self, GXmlDomDocument* doc, const gchar* local_name) {
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (doc != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp1_;
	_tmp2_ = local_name;
	_tmp3_ = g_strdup (_tmp2_);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp3_;
}


/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name and namespace.
   */
void gxml_gom_element_initialize_with_namespace (GXmlGomElement* self, const gchar* namespace_uri, const gchar* prefix, const gchar* local_name) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = local_name;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp1_;
	_tmp2_ = namespace_uri;
	_tmp3_ = g_strdup (_tmp2_);
	_g_free0 (self->_namespace_uri);
	self->_namespace_uri = _tmp3_;
	_tmp4_ = prefix;
	_tmp5_ = g_strdup (_tmp4_);
	_g_free0 (((GXmlGomNode*) self)->_prefix);
	((GXmlGomNode*) self)->_prefix = _tmp5_;
}


/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name, document and namespace.
   */
void gxml_gom_element_initialize_document_with_namespace (GXmlGomElement* self, GXmlDomDocument* doc, const gchar* namespace_uri, const gchar* prefix, const gchar* local_name) {
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (doc != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp1_;
	_tmp2_ = local_name;
	_tmp3_ = g_strdup (_tmp2_);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp3_;
	_tmp4_ = namespace_uri;
	_tmp5_ = g_strdup (_tmp4_);
	_g_free0 (self->_namespace_uri);
	self->_namespace_uri = _tmp5_;
	_tmp6_ = prefix;
	_tmp7_ = g_strdup (_tmp6_);
	_g_free0 (((GXmlGomNode*) self)->_prefix);
	((GXmlGomNode*) self)->_prefix = _tmp7_;
}


static gchar* gxml_gom_element_real_get_attribute (GXmlDomElement* base, const gchar* name) {
	GXmlGomElement * self;
	gchar* result = NULL;
	gchar* s = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GXmlGomElementAttributes* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gpointer _tmp5_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = name;
	_tmp1_ = gxml_gom_object_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) self) : NULL, _tmp0_);
	s = _tmp1_;
	_tmp2_ = s;
	if (_tmp2_ != NULL) {
		result = s;
		return result;
	}
	_tmp3_ = self->_attributes;
	_tmp4_ = name;
	_tmp5_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp3_, _tmp4_);
	result = (gchar*) _tmp5_;
	_g_free0 (s);
	return result;
}


static gchar* gxml_gom_element_real_get_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* local_name) {
	GXmlGomElement * self;
	gchar* result = NULL;
	gchar* nsp = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gchar* name = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GXmlGomElementAttributes* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gpointer _tmp16_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	nsp = NULL;
	_tmp1_ = namespace_uri;
	if (g_strcmp0 (_tmp1_, "http://www.w3.org/2000/xmlns/") == 0) {
		const gchar* _tmp2_ = NULL;
		_tmp2_ = local_name;
		_tmp0_ = g_strcmp0 (_tmp2_, "xmlns") != 0;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gchar* _tmp3_ = NULL;
		_tmp3_ = g_strdup ("xmlns");
		_g_free0 (nsp);
		nsp = _tmp3_;
	} else {
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		_tmp4_ = namespace_uri;
		_tmp5_ = gxml_gom_element_lookup_prefix (self, _tmp4_);
		_g_free0 (nsp);
		nsp = _tmp5_;
	}
	_tmp6_ = local_name;
	_tmp7_ = g_strdup (_tmp6_);
	name = _tmp7_;
	_tmp8_ = nsp;
	if (_tmp8_ != NULL) {
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		_tmp9_ = nsp;
		_tmp10_ = g_strconcat (_tmp9_, ":", NULL);
		_tmp11_ = _tmp10_;
		_tmp12_ = local_name;
		_tmp13_ = g_strconcat (_tmp11_, _tmp12_, NULL);
		_g_free0 (name);
		name = _tmp13_;
		_g_free0 (_tmp11_);
	}
	_tmp14_ = self->_attributes;
	_tmp15_ = name;
	_tmp16_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp14_, _tmp15_);
	result = (gchar*) _tmp16_;
	_g_free0 (name);
	_g_free0 (nsp);
	return result;
}


static void gxml_gom_element_real_set_attribute (GXmlDomElement* base, const gchar* name, const gchar* value, GError** error) {
	GXmlGomElement * self;
	gboolean res = FALSE;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GXmlGomAttr* a = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GXmlGomAttr* _tmp6_ = NULL;
	GXmlDomNamedNodeMap* _tmp7_ = NULL;
	GXmlDomNamedNodeMap* _tmp8_ = NULL;
	GXmlDomNamedNodeMap* _tmp9_ = NULL;
	GXmlGomAttr* _tmp10_ = NULL;
	GXmlDomNode* _tmp11_ = NULL;
	GXmlDomNode* _tmp12_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = name;
	_tmp1_ = value;
	_tmp2_ = gxml_gom_object_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) self) : NULL, _tmp0_, _tmp1_);
	res = _tmp2_;
	_tmp3_ = res;
	if (_tmp3_) {
		return;
	}
	_tmp4_ = name;
	_tmp5_ = value;
	_tmp6_ = gxml_gom_attr_new ((GXmlDomElement*) self, _tmp4_, _tmp5_);
	a = _tmp6_;
	_tmp7_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_;
	_tmp10_ = a;
	_tmp11_ = gxml_dom_named_node_map_set_named_item (_tmp9_, (GXmlDomNode*) _tmp10_, &_inner_error_);
	_tmp12_ = _tmp11_;
	_g_object_unref0 (_tmp12_);
	_g_object_unref0 (_tmp9_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (a);
		return;
	}
	_g_object_unref0 (a);
}


static void gxml_gom_element_real_set_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* name, const gchar* value, GError** error) {
	GXmlGomElement * self;
	gchar* p = NULL;
	gchar* _tmp0_ = NULL;
	gchar* n = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp24_ = FALSE;
	const gchar* _tmp25_ = NULL;
	gboolean _tmp29_ = FALSE;
	const gchar* _tmp30_ = NULL;
	gboolean _tmp34_ = FALSE;
	const gchar* _tmp35_ = NULL;
	gboolean _tmp39_ = FALSE;
	gboolean _tmp40_ = FALSE;
	const gchar* _tmp41_ = NULL;
	gboolean _tmp46_ = FALSE;
	gboolean _tmp47_ = FALSE;
	const gchar* _tmp48_ = NULL;
	GXmlGomAttr* a = NULL;
	const gchar* _tmp53_ = NULL;
	const gchar* _tmp54_ = NULL;
	const gchar* _tmp55_ = NULL;
	const gchar* _tmp56_ = NULL;
	GXmlGomAttr* _tmp57_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = g_strdup ("");
	p = _tmp0_;
	_tmp1_ = name;
	_tmp2_ = g_strdup (_tmp1_);
	n = _tmp2_;
	_tmp3_ = name;
	_tmp4_ = string_contains (_tmp3_, ":");
	if (_tmp4_) {
		gchar** s = NULL;
		const gchar* _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		gint s_length1 = 0;
		gint _s_size_ = 0;
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		gchar** _tmp11_ = NULL;
		gint _tmp11__length1 = 0;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		_tmp5_ = name;
		_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ":", 0);
		s = _tmp7_;
		s_length1 = _vala_array_length (_tmp6_);
		_s_size_ = s_length1;
		_tmp8_ = s;
		_tmp8__length1 = s_length1;
		if (_tmp8__length1 != 2) {
			const gchar* _tmp9_ = NULL;
			GError* _tmp10_ = NULL;
			_tmp9_ = _ ("Invalid attribute name. Just one prefix is allowed");
			_tmp10_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp9_);
			_inner_error_ = _tmp10_;
			g_propagate_error (error, _inner_error_);
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (p);
			return;
		}
		_tmp11_ = s;
		_tmp11__length1 = s_length1;
		_tmp12_ = _tmp11_[0];
		_tmp13_ = g_strdup (_tmp12_);
		_g_free0 (p);
		p = _tmp13_;
		_tmp14_ = s;
		_tmp14__length1 = s_length1;
		_tmp15_ = _tmp14_[1];
		_tmp16_ = g_strdup (_tmp15_);
		_g_free0 (n);
		n = _tmp16_;
		_tmp17_ = n;
		_tmp18_ = string_contains (_tmp17_, ":");
		if (_tmp18_) {
			const gchar* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			GError* _tmp21_ = NULL;
			_tmp19_ = _ ("Invalid attribute name. Invalid use of colon: %s");
			_tmp20_ = n;
			_tmp21_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp19_, _tmp20_);
			_inner_error_ = _tmp21_;
			g_propagate_error (error, _inner_error_);
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (p);
			return;
		}
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	} else {
		const gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		_tmp22_ = name;
		_tmp23_ = g_strdup (_tmp22_);
		_g_free0 (n);
		n = _tmp23_;
	}
	_tmp25_ = namespace_uri;
	if (_tmp25_ == NULL) {
		const gchar* _tmp26_ = NULL;
		_tmp26_ = p;
		_tmp24_ = g_strcmp0 (_tmp26_, "") == 0;
	} else {
		_tmp24_ = FALSE;
	}
	if (_tmp24_) {
		const gchar* _tmp27_ = NULL;
		GError* _tmp28_ = NULL;
		_tmp27_ = _ ("Invalid namespace. If prefix is null, namespace URI should not be null");
		_tmp28_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp27_);
		_inner_error_ = _tmp28_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp30_ = p;
	if (g_strcmp0 (_tmp30_, "xml") == 0) {
		const gchar* _tmp31_ = NULL;
		_tmp31_ = namespace_uri;
		_tmp29_ = g_strcmp0 (_tmp31_, "http://www.w3.org/2000/xmlns/") != 0;
	} else {
		_tmp29_ = FALSE;
	}
	if (_tmp29_) {
		const gchar* _tmp32_ = NULL;
		GError* _tmp33_ = NULL;
		_tmp32_ = _ ("Invalid namespace. If prefix is xml, namespace URI should be http://ww" \
"w.w3.org/2000/xmlns/");
		_tmp33_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp32_);
		_inner_error_ = _tmp33_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp35_ = p;
	if (g_strcmp0 (_tmp35_, "xmlns") == 0) {
		const gchar* _tmp36_ = NULL;
		_tmp36_ = namespace_uri;
		_tmp34_ = g_strcmp0 (_tmp36_, "http://www.w3.org/2000/xmlns/") != 0;
	} else {
		_tmp34_ = FALSE;
	}
	if (_tmp34_) {
		const gchar* _tmp37_ = NULL;
		GError* _tmp38_ = NULL;
		_tmp37_ = _ ("Invalid namespace. If attribute's prefix is xmlns, namespace URI shoul" \
"d be http://www.w3.org/2000/xmlns/");
		_tmp38_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp37_);
		_inner_error_ = _tmp38_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp41_ = p;
	if (g_strcmp0 (_tmp41_, "") == 0) {
		const gchar* _tmp42_ = NULL;
		_tmp42_ = n;
		_tmp40_ = g_strcmp0 (_tmp42_, "xmlns") == 0;
	} else {
		_tmp40_ = FALSE;
	}
	if (_tmp40_) {
		const gchar* _tmp43_ = NULL;
		_tmp43_ = namespace_uri;
		_tmp39_ = g_strcmp0 (_tmp43_, "http://www.w3.org/2000/xmlns/") != 0;
	} else {
		_tmp39_ = FALSE;
	}
	if (_tmp39_) {
		const gchar* _tmp44_ = NULL;
		GError* _tmp45_ = NULL;
		_tmp44_ = _ ("Invalid namespace. If attribute's name is xmlns, namespace URI should " \
"be http://www.w3.org/2000/xmlns/");
		_tmp45_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp44_);
		_inner_error_ = _tmp45_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp48_ = p;
	if (g_strcmp0 (_tmp48_, "") == 0) {
		const gchar* _tmp49_ = NULL;
		_tmp49_ = n;
		_tmp47_ = g_strcmp0 (_tmp49_, "xmlns") != 0;
	} else {
		_tmp47_ = FALSE;
	}
	if (_tmp47_) {
		const gchar* _tmp50_ = NULL;
		_tmp50_ = n;
		_tmp46_ = g_strcmp0 (_tmp50_, "xml") != 0;
	} else {
		_tmp46_ = FALSE;
	}
	if (_tmp46_) {
		const gchar* _tmp51_ = NULL;
		GError* _tmp52_ = NULL;
		_tmp51_ = _ ("Invalid attribute name. No prefixed attributes should use xmlns name");
		_tmp52_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp51_);
		_inner_error_ = _tmp52_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp53_ = namespace_uri;
	_tmp54_ = p;
	_tmp55_ = n;
	_tmp56_ = value;
	_tmp57_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) self, _tmp53_, _tmp54_, _tmp55_, _tmp56_);
	a = _tmp57_;
	{
		GXmlGomElementAttributes* _tmp58_ = NULL;
		GXmlGomAttr* _tmp59_ = NULL;
		GXmlDomNode* _tmp60_ = NULL;
		GXmlDomNode* _tmp61_ = NULL;
		_tmp58_ = self->_attributes;
		_tmp59_ = a;
		_tmp60_ = gxml_dom_named_node_map_set_named_item_ns ((GXmlDomNamedNodeMap*) _tmp58_, (GXmlDomNode*) _tmp59_, &_inner_error_);
		_tmp61_ = _tmp60_;
		_g_object_unref0 (_tmp61_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			goto __catch15_g_error;
		}
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp62_ = NULL;
		GError* _tmp63_ = NULL;
		const gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		GError* _tmp67_ = NULL;
		GError* _tmp68_ = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		_tmp62_ = _ ("Setting namespaced property error: ");
		_tmp63_ = e;
		_tmp64_ = _tmp63_->message;
		_tmp65_ = g_strconcat (_tmp62_, _tmp64_, NULL);
		_tmp66_ = _tmp65_;
		_tmp67_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp66_);
		_tmp68_ = _tmp67_;
		_g_free0 (_tmp66_);
		_inner_error_ = _tmp68_;
		_g_error_free0 (e);
		goto __finally15;
	}
	__finally15:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (a);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_g_object_unref0 (a);
	_g_free0 (n);
	_g_free0 (p);
}


static void gxml_gom_element_real_remove_attribute (GXmlDomElement* base, const gchar* name) {
	GXmlGomElement * self;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (name != NULL);
	_tmp0_ = name;
	_tmp1_ = gxml_gom_object_remove_attribute (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) self) : NULL, _tmp0_);
	if (_tmp1_) {
		return;
	}
	{
		GXmlDomNamedNodeMap* _tmp2_ = NULL;
		GXmlDomNamedNodeMap* _tmp3_ = NULL;
		GXmlDomNamedNodeMap* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomNode* _tmp7_ = NULL;
		_tmp2_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
		_tmp3_ = _tmp2_;
		_tmp4_ = _tmp3_;
		_tmp5_ = name;
		_tmp6_ = gxml_dom_named_node_map_remove_named_item (_tmp4_, _tmp5_, &_inner_error_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (_tmp7_);
		_g_object_unref0 (_tmp4_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			goto __catch16_g_error;
		}
	}
	goto __finally16;
	__catch16_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		_tmp8_ = _ ("Removing attribute Error: ");
		_tmp9_ = e;
		_tmp10_ = _tmp9_->message;
		_tmp11_ = g_strconcat (_tmp8_, _tmp10_, NULL);
		_tmp12_ = _tmp11_;
		g_warning ("GomElement.vala:556: %s", _tmp12_);
		_g_free0 (_tmp12_);
		_g_error_free0 (e);
	}
	__finally16:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
}


static void gxml_gom_element_real_remove_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* local_name) {
	GXmlGomElement * self;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (local_name != NULL);
	{
		GXmlDomNamedNodeMap* _tmp0_ = NULL;
		GXmlDomNamedNodeMap* _tmp1_ = NULL;
		GXmlDomNamedNodeMap* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		_tmp0_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
		_tmp1_ = _tmp0_;
		_tmp2_ = _tmp1_;
		_tmp3_ = namespace_uri;
		_tmp4_ = local_name;
		_tmp5_ = gxml_dom_named_node_map_remove_named_item_ns (_tmp2_, _tmp3_, _tmp4_, &_inner_error_);
		_tmp6_ = _tmp5_;
		_g_object_unref0 (_tmp6_);
		_g_object_unref0 (_tmp2_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			goto __catch17_g_error;
		}
	}
	goto __finally17;
	__catch17_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		_tmp7_ = _ ("Removing namespaced attribute Error: ");
		_tmp8_ = e;
		_tmp9_ = _tmp8_->message;
		_tmp10_ = g_strconcat (_tmp7_, _tmp9_, NULL);
		_tmp11_ = _tmp10_;
		g_warning ("GomElement.vala:561: %s", _tmp11_);
		_g_free0 (_tmp11_);
		_g_error_free0 (e);
	}
	__finally17:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
}


static gboolean gxml_gom_element_real_has_attribute (GXmlDomElement* base, const gchar* name) {
	GXmlGomElement * self;
	gboolean result = FALSE;
	GXmlGomElementAttributes* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (name != NULL, FALSE);
	_tmp0_ = self->_attributes;
	_tmp1_ = name;
	_tmp2_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, _tmp1_);
	result = _tmp2_;
	return result;
}


static gboolean gxml_gom_element_real_has_attribute_ns (GXmlDomElement* base, const gchar* namespace_uri, const gchar* local_name) {
	GXmlGomElement * self;
	gboolean result = FALSE;
	gchar* p = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GXmlDomNamedNodeMap* _tmp3_ = NULL;
	GXmlDomNamedNodeMap* _tmp4_ = NULL;
	GXmlDomNamedNodeMap* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, FALSE);
	_tmp0_ = namespace_uri;
	_tmp1_ = gxml_gom_element_lookup_prefix (self, _tmp0_);
	p = _tmp1_;
	_tmp2_ = p;
	if (_tmp2_ == NULL) {
		result = FALSE;
		_g_free0 (p);
		return result;
	}
	_tmp3_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = p;
	_tmp7_ = g_strconcat (_tmp6_, ":", NULL);
	_tmp8_ = _tmp7_;
	_tmp9_ = local_name;
	_tmp10_ = g_strconcat (_tmp8_, _tmp9_, NULL);
	_tmp11_ = _tmp10_;
	_tmp12_ = gee_map_has_key ((GeeMap*) _tmp5_, _tmp11_);
	_tmp13_ = _tmp12_;
	_g_free0 (_tmp11_);
	_g_free0 (_tmp8_);
	_g_object_unref0 (_tmp5_);
	result = _tmp13_;
	_g_free0 (p);
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_tag_name (GXmlDomElement* base, const gchar* local_name) {
	GXmlGomElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			GXmlDomNode* _tmp12_ = NULL;
			GXmlDomNode* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
			GXmlGDomHTMLCollection* _tmp21_ = NULL;
			GXmlDomNode* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			GXmlDomHTMLCollection* _tmp24_ = NULL;
			GXmlDomHTMLCollection* _tmp25_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomNode*) _tmp11_;
			_tmp12_ = n;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (n);
				continue;
			}
			_tmp13_ = n;
			_tmp14_ = gxml_dom_node_get_node_name (_tmp13_);
			_tmp15_ = _tmp14_;
			_tmp16_ = _tmp15_;
			_tmp17_ = local_name;
			_tmp18_ = g_strcmp0 (_tmp16_, _tmp17_) == 0;
			_g_free0 (_tmp16_);
			if (_tmp18_) {
				GXmlGDomHTMLCollection* _tmp19_ = NULL;
				GXmlDomNode* _tmp20_ = NULL;
				_tmp19_ = l;
				_tmp20_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp20_) : NULL);
			}
			_tmp21_ = l;
			_tmp22_ = n;
			_tmp23_ = local_name;
			_tmp24_ = gxml_dom_element_get_elements_by_tag_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp22_) : NULL, _tmp23_);
			_tmp25_ = _tmp24_;
			gee_array_list_add_all ((GeeArrayList*) _tmp21_, (GeeCollection*) _tmp25_);
			_g_object_unref0 (_tmp25_);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_tag_name_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name) {
	GXmlGomElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			GXmlDomNode* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			GXmlDomNode* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			gboolean _tmp19_ = FALSE;
			GXmlGDomHTMLCollection* _tmp27_ = NULL;
			GXmlDomNode* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
			GXmlDomHTMLCollection* _tmp31_ = NULL;
			GXmlDomHTMLCollection* _tmp32_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomNode*) _tmp11_;
			_tmp12_ = n;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (n);
				continue;
			}
			_tmp14_ = n;
			_tmp15_ = gxml_dom_node_get_node_name (_tmp14_);
			_tmp16_ = _tmp15_;
			_tmp17_ = _tmp16_;
			_tmp18_ = local_name;
			_tmp19_ = g_strcmp0 (_tmp17_, _tmp18_) == 0;
			_g_free0 (_tmp17_);
			if (_tmp19_) {
				GXmlDomNode* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				const gchar* _tmp24_ = NULL;
				_tmp20_ = n;
				_tmp21_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp20_) : NULL);
				_tmp22_ = _tmp21_;
				_tmp23_ = _tmp22_;
				_tmp24_ = namespace;
				_tmp13_ = g_strcmp0 (_tmp23_, _tmp24_) == 0;
				_g_free0 (_tmp23_);
			} else {
				_tmp13_ = FALSE;
			}
			if (_tmp13_) {
				GXmlGDomHTMLCollection* _tmp25_ = NULL;
				GXmlDomNode* _tmp26_ = NULL;
				_tmp25_ = l;
				_tmp26_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp25_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp26_) : NULL);
			}
			_tmp27_ = l;
			_tmp28_ = n;
			_tmp29_ = namespace;
			_tmp30_ = local_name;
			_tmp31_ = gxml_dom_element_get_elements_by_tag_name_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp28_) : NULL, _tmp29_, _tmp30_);
			_tmp32_ = _tmp31_;
			gee_array_list_add_all ((GeeArrayList*) _tmp27_, (GeeCollection*) _tmp32_);
			_g_object_unref0 (_tmp32_);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static void _vala_array_add8 (gchar*** array, int* length, int* size, gchar* value) {
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}


static void _vala_array_add9 (gchar*** array, int* length, int* size, gchar* value) {
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}


static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_class_name (GXmlDomElement* base, const gchar* class_names) {
	GXmlGomElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** cs = NULL;
	gchar** _tmp2_ = NULL;
	gint cs_length1 = 0;
	gint _cs_size_ = 0;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (class_names != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = class_names;
	if (g_strcmp0 (_tmp1_, "") == 0) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp2_ = g_new0 (gchar*, 0 + 1);
	cs = _tmp2_;
	cs_length1 = 0;
	_cs_size_ = cs_length1;
	_tmp3_ = class_names;
	_tmp4_ = string_contains (_tmp3_, " ");
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		_tmp5_ = class_names;
		_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, " ", 0);
		cs = (_vala_array_free (cs, cs_length1, (GDestroyNotify) g_free), NULL);
		cs = _tmp7_;
		cs_length1 = _vala_array_length (_tmp6_);
		_cs_size_ = cs_length1;
	} else {
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		_tmp8_ = cs;
		_tmp8__length1 = cs_length1;
		_tmp9_ = class_names;
		_tmp10_ = g_strdup (_tmp9_);
		_vala_array_add8 (&cs, &cs_length1, &_cs_size_, _tmp10_);
	}
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
		gint _n_index = 0;
		_tmp11_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp12_ = _tmp11_;
		_n_list = _tmp12_;
		_tmp13_ = _n_list;
		_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
		_tmp15_ = _tmp14_;
		_n_size = _tmp15_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp16_ = 0;
			gint _tmp17_ = 0;
			gint _tmp18_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp19_ = NULL;
			gint _tmp20_ = 0;
			gpointer _tmp21_ = NULL;
			GXmlDomNode* _tmp22_ = NULL;
			gchar* cls = NULL;
			GXmlDomNode* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			const gchar* _tmp25_ = NULL;
			GXmlGDomHTMLCollection* _tmp51_ = NULL;
			GXmlDomNode* _tmp52_ = NULL;
			const gchar* _tmp53_ = NULL;
			GXmlDomHTMLCollection* _tmp54_ = NULL;
			GXmlDomHTMLCollection* _tmp55_ = NULL;
			_tmp16_ = _n_index;
			_n_index = _tmp16_ + 1;
			_tmp17_ = _n_index;
			_tmp18_ = _n_size;
			if (!(_tmp17_ < _tmp18_)) {
				break;
			}
			_tmp19_ = _n_list;
			_tmp20_ = _n_index;
			_tmp21_ = gee_list_get ((GeeList*) _tmp19_, _tmp20_);
			n = (GXmlDomNode*) _tmp21_;
			_tmp22_ = n;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (n);
				continue;
			}
			_tmp23_ = n;
			_tmp24_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp23_) : NULL, "class");
			cls = _tmp24_;
			_tmp25_ = cls;
			if (_tmp25_ != NULL) {
				gchar** ncls = NULL;
				gchar** _tmp26_ = NULL;
				gint ncls_length1 = 0;
				gint _ncls_size_ = 0;
				const gchar* _tmp27_ = NULL;
				gboolean _tmp28_ = FALSE;
				gint found = 0;
				gchar** _tmp35_ = NULL;
				gint _tmp35__length1 = 0;
				gint _tmp42_ = 0;
				gchar** _tmp43_ = NULL;
				gint _tmp43__length1 = 0;
				_tmp26_ = g_new0 (gchar*, 0 + 1);
				ncls = _tmp26_;
				ncls_length1 = 0;
				_ncls_size_ = ncls_length1;
				_tmp27_ = cls;
				_tmp28_ = string_contains (_tmp27_, " ");
				if (_tmp28_) {
					const gchar* _tmp29_ = NULL;
					gchar** _tmp30_ = NULL;
					gchar** _tmp31_ = NULL;
					_tmp29_ = cls;
					_tmp31_ = _tmp30_ = g_strsplit (_tmp29_, " ", 0);
					ncls = (_vala_array_free (ncls, ncls_length1, (GDestroyNotify) g_free), NULL);
					ncls = _tmp31_;
					ncls_length1 = _vala_array_length (_tmp30_);
					_ncls_size_ = ncls_length1;
				} else {
					gchar** _tmp32_ = NULL;
					gint _tmp32__length1 = 0;
					const gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
					_tmp32_ = ncls;
					_tmp32__length1 = ncls_length1;
					_tmp33_ = cls;
					_tmp34_ = g_strdup (_tmp33_);
					_vala_array_add9 (&ncls, &ncls_length1, &_ncls_size_, _tmp34_);
				}
				found = 0;
				_tmp35_ = cs;
				_tmp35__length1 = cs_length1;
				{
					gchar** cl_collection = NULL;
					gint cl_collection_length1 = 0;
					gint _cl_collection_size_ = 0;
					gint cl_it = 0;
					cl_collection = _tmp35_;
					cl_collection_length1 = _tmp35__length1;
					for (cl_it = 0; cl_it < _tmp35__length1; cl_it = cl_it + 1) {
						gchar* _tmp36_ = NULL;
						gchar* cl = NULL;
						_tmp36_ = g_strdup (cl_collection[cl_it]);
						cl = _tmp36_;
						{
							gchar** _tmp37_ = NULL;
							gint _tmp37__length1 = 0;
							_tmp37_ = ncls;
							_tmp37__length1 = ncls_length1;
							{
								gchar** ncl_collection = NULL;
								gint ncl_collection_length1 = 0;
								gint _ncl_collection_size_ = 0;
								gint ncl_it = 0;
								ncl_collection = _tmp37_;
								ncl_collection_length1 = _tmp37__length1;
								for (ncl_it = 0; ncl_it < _tmp37__length1; ncl_it = ncl_it + 1) {
									gchar* _tmp38_ = NULL;
									gchar* ncl = NULL;
									_tmp38_ = g_strdup (ncl_collection[ncl_it]);
									ncl = _tmp38_;
									{
										const gchar* _tmp39_ = NULL;
										const gchar* _tmp40_ = NULL;
										_tmp39_ = cl;
										_tmp40_ = ncl;
										if (g_strcmp0 (_tmp39_, _tmp40_) == 0) {
											gint _tmp41_ = 0;
											_tmp41_ = found;
											found = _tmp41_ + 1;
										}
										_g_free0 (ncl);
									}
								}
							}
							_g_free0 (cl);
						}
					}
				}
				_tmp42_ = found;
				_tmp43_ = cs;
				_tmp43__length1 = cs_length1;
				if (_tmp42_ == _tmp43__length1) {
					GXmlGDomHTMLCollection* _tmp44_ = NULL;
					gint _tmp45_ = 0;
					gint _tmp46_ = 0;
					_tmp44_ = l;
					_tmp45_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp44_);
					_tmp46_ = _tmp45_;
					if (_tmp46_ == 0) {
						GXmlGDomHTMLCollection* _tmp47_ = NULL;
						GXmlDomNode* _tmp48_ = NULL;
						_tmp47_ = l;
						_tmp48_ = n;
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp47_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp48_) : NULL);
					} else {
						GXmlGDomHTMLCollection* _tmp49_ = NULL;
						GXmlDomNode* _tmp50_ = NULL;
						_tmp49_ = l;
						_tmp50_ = n;
						gee_abstract_list_insert ((GeeAbstractList*) _tmp49_, 0, G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp50_) : NULL);
					}
				}
				ncls = (_vala_array_free (ncls, ncls_length1, (GDestroyNotify) g_free), NULL);
			}
			_tmp51_ = l;
			_tmp52_ = n;
			_tmp53_ = class_names;
			_tmp54_ = gxml_dom_element_get_elements_by_class_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp52_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp52_) : NULL, _tmp53_);
			_tmp55_ = _tmp54_;
			gee_array_list_add_all ((GeeArrayList*) _tmp51_, (GeeCollection*) _tmp55_);
			_g_object_unref0 (_tmp55_);
			_g_free0 (cls);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	cs = (_vala_array_free (cs, cs_length1, (GDestroyNotify) g_free), NULL);
	return result;
}


GXmlGomElement* gxml_gom_element_construct (GType object_type) {
	GXmlGomElement * self = NULL;
	self = (GXmlGomElement*) gxml_gom_node_construct (object_type);
	return self;
}


GXmlGomElement* gxml_gom_element_new (void) {
	return gxml_gom_element_construct (GXML_TYPE_GOM_ELEMENT);
}


static GXmlDomElement* gxml_gom_element_real_get_previous_element_sibling (GXmlDomNonDocumentTypeChildNode* base) {
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ != NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		gint i = 0;
		GXmlDomNode* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlDomNodeList* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		GXmlDomNode* n = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlDomNodeList* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		GXmlDomNode* _tmp20_ = NULL;
		GXmlDomNode* _tmp21_ = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gee_list_index_of ((GeeList*) _tmp9_, (GXmlDomNode*) self);
		_tmp11_ = _tmp10_;
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (_tmp6_);
		i = _tmp11_;
		_tmp12_ = i;
		if (_tmp12_ == 0) {
			result = NULL;
			return result;
		}
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = gxml_dom_node_get_child_nodes (_tmp15_);
		_tmp17_ = _tmp16_;
		_tmp18_ = _tmp17_;
		_tmp19_ = i;
		_tmp20_ = gxml_dom_node_list_item (_tmp18_, _tmp19_ - 1);
		_tmp21_ = _tmp20_;
		_g_object_unref0 (_tmp18_);
		_g_object_unref0 (_tmp15_);
		n = _tmp21_;
		_tmp22_ = n;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_ELEMENT)) {
			GXmlDomNode* _tmp23_ = NULL;
			_tmp23_ = n;
			result = G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
			_g_object_unref0 (n);
			return result;
		}
		result = NULL;
		_g_object_unref0 (n);
		return result;
	}
	result = NULL;
	return result;
}


static GXmlDomElement* gxml_gom_element_real_get_next_element_sibling (GXmlDomNonDocumentTypeChildNode* base) {
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ != NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		gint i = 0;
		GXmlDomNode* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlDomNodeList* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlDomNodeList* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		gint _tmp20_ = 0;
		gboolean _tmp21_ = FALSE;
		GXmlDomNode* n = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomNode* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gee_list_index_of ((GeeList*) _tmp9_, (GXmlDomNode*) self);
		_tmp11_ = _tmp10_;
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (_tmp6_);
		i = _tmp11_;
		_tmp12_ = i;
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = gxml_dom_node_get_child_nodes (_tmp15_);
		_tmp17_ = _tmp16_;
		_tmp18_ = _tmp17_;
		_tmp19_ = gxml_dom_node_list_get_length (_tmp18_);
		_tmp20_ = _tmp19_;
		_tmp21_ = _tmp12_ == (_tmp20_ - 1);
		_g_object_unref0 (_tmp18_);
		_g_object_unref0 (_tmp15_);
		if (_tmp21_) {
			result = NULL;
			return result;
		}
		_tmp22_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_;
		_tmp25_ = gxml_dom_node_get_child_nodes (_tmp24_);
		_tmp26_ = _tmp25_;
		_tmp27_ = _tmp26_;
		_tmp28_ = i;
		_tmp29_ = gxml_dom_node_list_item (_tmp27_, _tmp28_ + 1);
		_tmp30_ = _tmp29_;
		_g_object_unref0 (_tmp27_);
		_g_object_unref0 (_tmp24_);
		n = _tmp30_;
		_tmp31_ = n;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT)) {
			GXmlDomNode* _tmp32_ = NULL;
			_tmp32_ = n;
			result = G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
			_g_object_unref0 (n);
			return result;
		}
		result = NULL;
		_g_object_unref0 (n);
		return result;
	}
	result = NULL;
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_element_real_get_children (GXmlDomParentNode* base) {
	GXmlDomHTMLCollection* result;
	GXmlGomElement* self;
	GXmlDomElementList* l = NULL;
	GXmlDomElementList* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_element_list_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			GXmlDomNode* _tmp12_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomNode*) _tmp11_;
			_tmp12_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
				GXmlDomElementList* _tmp13_ = NULL;
				GXmlDomNode* _tmp14_ = NULL;
				_tmp13_ = l;
				_tmp14_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomElement* gxml_gom_element_real_get_first_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static GXmlDomElement* gxml_gom_element_real_get_last_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static gint gxml_gom_element_real_get_child_element_count (GXmlDomParentNode* base) {
	gint result;
	GXmlGomElement* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}


static gchar* gxml_gom_element_real_get_namespace_uri (GXmlDomElement* base) {
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = self->_namespace_uri;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static gchar* gxml_gom_element_real_get_prefix (GXmlDomElement* base) {
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_prefix;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static gchar* gxml_gom_element_real_get_local_name (GXmlDomElement* base) {
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_local_name;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static gchar* gxml_gom_element_real_get_tag_name (GXmlDomElement* base) {
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_local_name;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static gchar* gxml_gom_element_real_get_id (GXmlDomElement* base) {
	gchar* result;
	GXmlGomElement* self;
	gchar* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_element_get_attribute ((GXmlDomElement*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) self) : NULL), "id");
	result = _tmp0_;
	return result;
}


static void gxml_gom_element_real_set_id (GXmlDomElement* base, const gchar* value) {
	GXmlGomElement* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = value;
	gxml_gom_object_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) self) : NULL, "id", _tmp0_);
	g_object_notify ((GObject *) self, "id");
}


static gchar* gxml_gom_element_real_get_class_name (GXmlDomElement* base) {
	gchar* result;
	GXmlGomElement* self;
	gchar* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_element_get_attribute ((GXmlDomElement*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) self) : NULL), "class");
	result = _tmp0_;
	return result;
}


static void gxml_gom_element_real_set_class_name (GXmlDomElement* base, const gchar* value) {
	GXmlGomElement* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = value;
	gxml_gom_object_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) self) : NULL, "class", _tmp0_);
	g_object_notify ((GObject *) self, "class-name");
}


static GXmlDomTokenList* gxml_gom_element_real_get_class_list (GXmlDomElement* base) {
	GXmlDomTokenList* result;
	GXmlGomElement* self;
	GXmlGDomTokenList* _tmp0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_gdom_token_list_new ((GXmlDomElement*) self, "class");
	result = (GXmlDomTokenList*) _tmp0_;
	return result;
}


static GXmlDomNamedNodeMap* gxml_gom_element_real_get_attributes (GXmlDomElement* base) {
	GXmlDomNamedNodeMap* result;
	GXmlGomElement* self;
	GXmlGomElementAttributes* _tmp0_ = NULL;
	GXmlDomNamedNodeMap* _tmp1_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = self->_attributes;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap));
	result = _tmp1_;
	return result;
}


static GObject * gxml_gom_element_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GXmlGomElement * self;
	GXmlGomElementAttributes* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	parent_class = G_OBJECT_CLASS (gxml_gom_element_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	((GXmlGomNode*) self)->_node_type = GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE;
	_tmp0_ = gxml_gom_element_attributes_new (self);
	_g_object_unref0 (self->_attributes);
	self->_attributes = _tmp0_;
	_tmp1_ = g_strdup ("");
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp1_;
	return obj;
}


static GXmlDomNode* gxml_gom_element_attributes_real_item (GXmlDomNamedNodeMap* base, gint index) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGomElementAttributes*) base;
	result = NULL;
	return result;
}


GXmlGomElementAttributes* gxml_gom_element_attributes_construct (GType object_type, GXmlGomElement* element) {
	GXmlGomElementAttributes * self = NULL;
	GXmlGomElement* _tmp0_ = NULL;
	GXmlGomElement* _tmp1_ = NULL;
	g_return_val_if_fail (element != NULL, NULL);
	self = (GXmlGomElementAttributes*) gee_hash_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_tmp0_ = element;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->_element);
	self->_element = _tmp1_;
	return self;
}


GXmlGomElementAttributes* gxml_gom_element_attributes_new (GXmlGomElement* element) {
	return gxml_gom_element_attributes_construct (GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, element);
}


static GXmlDomNode* gxml_gom_element_attributes_real_get_named_item (GXmlDomNamedNodeMap* base, const gchar* name) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* ov = NULL;
	GXmlGomElement* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* p = NULL;
	gchar* _tmp9_ = NULL;
	gchar* ns = NULL;
	gchar* n = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gchar* val = NULL;
	const gchar* _tmp36_ = NULL;
	gpointer _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	GXmlDomNode* attr = NULL;
	gboolean _tmp39_ = FALSE;
	const gchar* _tmp40_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = name;
	if (g_strcmp0 (_tmp0_, "") == 0) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->_element;
	_tmp2_ = name;
	_tmp3_ = gxml_gom_object_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) _tmp1_) : NULL, _tmp2_);
	ov = _tmp3_;
	_tmp4_ = ov;
	if (_tmp4_ != NULL) {
		GXmlGomElement* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GXmlGomAttr* _tmp8_ = NULL;
		_tmp5_ = self->_element;
		_tmp6_ = name;
		_tmp7_ = ov;
		_tmp8_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp5_, _tmp6_, _tmp7_);
		result = (GXmlDomNode*) _tmp8_;
		_g_free0 (ov);
		return result;
	}
	_tmp9_ = g_strdup ("");
	p = _tmp9_;
	ns = NULL;
	_tmp10_ = name;
	_tmp11_ = g_strdup (_tmp10_);
	n = _tmp11_;
	_tmp12_ = name;
	_tmp13_ = string_contains (_tmp12_, ":");
	if (_tmp13_) {
		gchar** s = NULL;
		const gchar* _tmp14_ = NULL;
		gchar** _tmp15_ = NULL;
		gchar** _tmp16_ = NULL;
		gint s_length1 = 0;
		gint _s_size_ = 0;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		gchar** _tmp18_ = NULL;
		gint _tmp18__length1 = 0;
		const gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar** _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
		const gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp26_ = NULL;
		gboolean _tmp30_ = FALSE;
		const gchar* _tmp31_ = NULL;
		_tmp14_ = name;
		_tmp16_ = _tmp15_ = g_strsplit (_tmp14_, ":", 0);
		s = _tmp16_;
		s_length1 = _vala_array_length (_tmp15_);
		_s_size_ = s_length1;
		_tmp17_ = s;
		_tmp17__length1 = s_length1;
		if (_tmp17__length1 > 2) {
			result = NULL;
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (ns);
			_g_free0 (p);
			_g_free0 (ov);
			return result;
		}
		_tmp18_ = s;
		_tmp18__length1 = s_length1;
		_tmp19_ = _tmp18_[0];
		_tmp20_ = g_strdup (_tmp19_);
		_g_free0 (p);
		p = _tmp20_;
		_tmp21_ = s;
		_tmp21__length1 = s_length1;
		_tmp22_ = _tmp21_[1];
		_tmp23_ = g_strdup (_tmp22_);
		_g_free0 (n);
		n = _tmp23_;
		_tmp24_ = p;
		if (g_strcmp0 (_tmp24_, "xml") == 0) {
			gchar* _tmp25_ = NULL;
			_tmp25_ = g_strdup ("http://www.w3.org/2000/xmlns/");
			_g_free0 (ns);
			ns = _tmp25_;
		}
		_tmp26_ = p;
		if (g_strcmp0 (_tmp26_, "xmlns") == 0) {
			GXmlGomElement* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			_tmp27_ = self->_element;
			_tmp28_ = n;
			_tmp29_ = gxml_gom_element_lookup_namespace_uri (_tmp27_, _tmp28_);
			_g_free0 (ns);
			ns = _tmp29_;
		}
		_tmp31_ = p;
		if (g_strcmp0 (_tmp31_, "xmlns") != 0) {
			const gchar* _tmp32_ = NULL;
			_tmp32_ = p;
			_tmp30_ = g_strcmp0 (_tmp32_, "xml") != 0;
		} else {
			_tmp30_ = FALSE;
		}
		if (_tmp30_) {
			GXmlGomElement* _tmp33_ = NULL;
			const gchar* _tmp34_ = NULL;
			gchar* _tmp35_ = NULL;
			_tmp33_ = self->_element;
			_tmp34_ = p;
			_tmp35_ = gxml_gom_element_lookup_namespace_uri (_tmp33_, _tmp34_);
			_g_free0 (ns);
			ns = _tmp35_;
		}
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	}
	_tmp36_ = name;
	_tmp37_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp36_);
	val = (gchar*) _tmp37_;
	_tmp38_ = val;
	if (_tmp38_ == NULL) {
		result = NULL;
		_g_free0 (val);
		_g_free0 (n);
		_g_free0 (ns);
		_g_free0 (p);
		_g_free0 (ov);
		return result;
	}
	attr = NULL;
	_tmp40_ = p;
	if (_tmp40_ == NULL) {
		_tmp39_ = TRUE;
	} else {
		const gchar* _tmp41_ = NULL;
		_tmp41_ = p;
		_tmp39_ = g_strcmp0 (_tmp41_, "") == 0;
	}
	if (_tmp39_) {
		GXmlGomElement* _tmp42_ = NULL;
		const gchar* _tmp43_ = NULL;
		const gchar* _tmp44_ = NULL;
		GXmlGomAttr* _tmp45_ = NULL;
		_tmp42_ = self->_element;
		_tmp43_ = n;
		_tmp44_ = val;
		_tmp45_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp42_, _tmp43_, _tmp44_);
		_g_object_unref0 (attr);
		attr = (GXmlDomNode*) _tmp45_;
	} else {
		GXmlGomElement* _tmp46_ = NULL;
		const gchar* _tmp47_ = NULL;
		const gchar* _tmp48_ = NULL;
		const gchar* _tmp49_ = NULL;
		const gchar* _tmp50_ = NULL;
		GXmlGomAttr* _tmp51_ = NULL;
		_tmp46_ = self->_element;
		_tmp47_ = ns;
		_tmp48_ = p;
		_tmp49_ = n;
		_tmp50_ = val;
		_tmp51_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) _tmp46_, _tmp47_, _tmp48_, _tmp49_, _tmp50_);
		_g_object_unref0 (attr);
		attr = (GXmlDomNode*) _tmp51_;
	}
	result = attr;
	_g_free0 (val);
	_g_free0 (n);
	_g_free0 (ns);
	_g_free0 (p);
	_g_free0 (ov);
	return result;
}


/**
     * Takes given {@link DomNode} as a {@link DomAttr} and use its name and
     * value to set a property in {@link DomElement} ignoring node's prefix and
     * namespace
     */
static GXmlDomNode* gxml_gom_element_attributes_real_set_named_item (GXmlDomNamedNodeMap* base, GXmlDomNode* node, GError** error) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gboolean _tmp0_ = FALSE;
	GXmlDomNode* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	GXmlDomNode* _tmp18_ = NULL;
	GXmlDomNode* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	GXmlDomNode* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	GXmlGomElement* _tmp29_ = NULL;
	GXmlDomNode* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	GXmlDomNode* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	GXmlGomAttr* _tmp38_ = NULL;
	GXmlDomNode* _tmp39_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = node;
	_tmp2_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp1_) : NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = string_contains (_tmp4_, ":");
	_tmp6_ = _tmp5_;
	_g_free0 (_tmp4_);
	if (_tmp6_) {
		_tmp0_ = TRUE;
	} else {
		GXmlDomNode* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		_tmp7_ = node;
		_tmp8_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp7_) : NULL);
		_tmp9_ = _tmp8_;
		_tmp10_ = _tmp9_;
		_tmp0_ = g_strcmp0 (_tmp10_, "") == 0;
		_g_free0 (_tmp10_);
	}
	if (_tmp0_) {
		const gchar* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		GError* _tmp17_ = NULL;
		_tmp11_ = _ ("Invalid attribute name: %s");
		_tmp12_ = node;
		_tmp13_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp12_) : NULL);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_CHARACTER_ERROR, _tmp11_, _tmp15_);
		_tmp17_ = _tmp16_;
		_g_free0 (_tmp15_);
		_inner_error_ = _tmp17_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp18_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ATTR)) {
		const gchar* _tmp19_ = NULL;
		GError* _tmp20_ = NULL;
		_tmp19_ = _ ("Invalid node type. DomAttr was expected");
		_tmp20_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp19_);
		_inner_error_ = _tmp20_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp21_ = node;
	_tmp22_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp21_) : NULL);
	_tmp23_ = _tmp22_;
	_tmp24_ = _tmp23_;
	_tmp25_ = node;
	_tmp26_ = gxml_dom_node_get_node_value (_tmp25_);
	_tmp27_ = _tmp26_;
	_tmp28_ = _tmp27_;
	gee_abstract_map_set ((GeeAbstractMap*) self, _tmp24_, _tmp28_);
	_g_free0 (_tmp28_);
	_g_free0 (_tmp24_);
	_tmp29_ = self->_element;
	_tmp30_ = node;
	_tmp31_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp30_) : NULL);
	_tmp32_ = _tmp31_;
	_tmp33_ = _tmp32_;
	_tmp34_ = node;
	_tmp35_ = gxml_dom_node_get_node_value (_tmp34_);
	_tmp36_ = _tmp35_;
	_tmp37_ = _tmp36_;
	_tmp38_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp29_, _tmp33_, _tmp37_);
	_tmp39_ = (GXmlDomNode*) _tmp38_;
	_g_free0 (_tmp37_);
	_g_free0 (_tmp33_);
	result = _tmp39_;
	return result;
}


static GXmlDomNode* gxml_gom_element_attributes_real_remove_named_item (GXmlDomNamedNodeMap* base, const gchar* name, GError** error) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gchar* v = NULL;
	const gchar* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GXmlGomAttr* n = NULL;
	GXmlGomElement* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GXmlGomAttr* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = name;
	_tmp1_ = string_contains (_tmp0_, ":");
	if (_tmp1_) {
		result = NULL;
		return result;
	}
	_tmp2_ = name;
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp2_);
	v = (gchar*) _tmp3_;
	_tmp4_ = v;
	if (_tmp4_ == NULL) {
		result = NULL;
		_g_free0 (v);
		return result;
	}
	_tmp5_ = self->_element;
	_tmp6_ = name;
	_tmp7_ = v;
	_tmp8_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp5_, _tmp6_, _tmp7_);
	n = _tmp8_;
	_tmp9_ = name;
	gee_abstract_map_unset ((GeeAbstractMap*) self, _tmp9_, NULL);
	result = (GXmlDomNode*) n;
	_g_free0 (v);
	return result;
}


static GXmlDomNode* gxml_gom_element_attributes_real_remove_named_item_ns (GXmlDomNamedNodeMap* base, const gchar* namespace_uri, const gchar* local_name, GError** error) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gchar* nsp = NULL;
	GXmlGomElement* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_ = NULL;
	gchar* v = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gpointer _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	GXmlGomAttr* n = NULL;
	GXmlGomElement* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	GXmlGomAttr* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = local_name;
	_tmp1_ = string_contains (_tmp0_, ":");
	if (_tmp1_) {
		result = NULL;
		return result;
	}
	_tmp2_ = self->_element;
	_tmp3_ = namespace_uri;
	_tmp4_ = gxml_gom_element_lookup_prefix (_tmp2_, _tmp3_);
	nsp = _tmp4_;
	_tmp6_ = nsp;
	if (_tmp6_ == NULL) {
		_tmp5_ = TRUE;
	} else {
		const gchar* _tmp7_ = NULL;
		_tmp7_ = nsp;
		_tmp5_ = g_strcmp0 (_tmp7_, "") == 0;
	}
	if (_tmp5_) {
		result = NULL;
		_g_free0 (nsp);
		return result;
	}
	_tmp8_ = nsp;
	_tmp9_ = g_strconcat (_tmp8_, ":", NULL);
	_tmp10_ = _tmp9_;
	_tmp11_ = local_name;
	_tmp12_ = g_strconcat (_tmp10_, _tmp11_, NULL);
	_tmp13_ = _tmp12_;
	_tmp14_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp13_);
	_tmp15_ = (gchar*) _tmp14_;
	_g_free0 (_tmp13_);
	_g_free0 (_tmp10_);
	v = _tmp15_;
	_tmp16_ = v;
	if (_tmp16_ == NULL) {
		result = NULL;
		_g_free0 (v);
		_g_free0 (nsp);
		return result;
	}
	_tmp17_ = self->_element;
	_tmp18_ = namespace_uri;
	_tmp19_ = nsp;
	_tmp20_ = local_name;
	_tmp21_ = v;
	_tmp22_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) _tmp17_, _tmp18_, _tmp19_, _tmp20_, _tmp21_);
	n = _tmp22_;
	_tmp23_ = nsp;
	_tmp24_ = g_strconcat (_tmp23_, ":", NULL);
	_tmp25_ = _tmp24_;
	_tmp26_ = local_name;
	_tmp27_ = g_strconcat (_tmp25_, _tmp26_, NULL);
	_tmp28_ = _tmp27_;
	gee_abstract_map_unset ((GeeAbstractMap*) self, _tmp28_, NULL);
	_g_free0 (_tmp28_);
	_g_free0 (_tmp25_);
	result = (GXmlDomNode*) n;
	_g_free0 (v);
	_g_free0 (nsp);
	return result;
}


static GXmlDomNode* gxml_gom_element_attributes_real_get_named_item_ns (GXmlDomNamedNodeMap* base, const gchar* namespace_uri, const gchar* local_name, GError** error) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gchar* nsp = NULL;
	GXmlGomElement* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* v = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gpointer _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GXmlGomAttr* n = NULL;
	GXmlGomElement* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	GXmlGomAttr* _tmp20_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = local_name;
	_tmp1_ = string_contains (_tmp0_, ":");
	if (_tmp1_) {
		result = NULL;
		return result;
	}
	_tmp2_ = self->_element;
	_tmp3_ = namespace_uri;
	_tmp4_ = gxml_gom_element_lookup_prefix (_tmp2_, _tmp3_);
	nsp = _tmp4_;
	_tmp5_ = nsp;
	if (_tmp5_ == NULL) {
		result = NULL;
		_g_free0 (nsp);
		return result;
	}
	_tmp6_ = nsp;
	_tmp7_ = g_strconcat (_tmp6_, ":", NULL);
	_tmp8_ = _tmp7_;
	_tmp9_ = local_name;
	_tmp10_ = g_strconcat (_tmp8_, _tmp9_, NULL);
	_tmp11_ = _tmp10_;
	_tmp12_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp11_);
	_tmp13_ = (gchar*) _tmp12_;
	_g_free0 (_tmp11_);
	_g_free0 (_tmp8_);
	v = _tmp13_;
	_tmp14_ = v;
	if (_tmp14_ == NULL) {
		result = NULL;
		_g_free0 (v);
		_g_free0 (nsp);
		return result;
	}
	_tmp15_ = self->_element;
	_tmp16_ = namespace_uri;
	_tmp17_ = nsp;
	_tmp18_ = local_name;
	_tmp19_ = v;
	_tmp20_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) _tmp15_, _tmp16_, _tmp17_, _tmp18_, _tmp19_);
	n = _tmp20_;
	result = (GXmlDomNode*) n;
	_g_free0 (v);
	_g_free0 (nsp);
	return result;
}


static GXmlDomNode* gxml_gom_element_attributes_real_set_named_item_ns (GXmlDomNamedNodeMap* base, GXmlDomNode* node, GError** error) {
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gboolean _tmp0_ = FALSE;
	GXmlDomNode* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	GXmlDomNode* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp38_ = FALSE;
	GXmlDomNode* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	gboolean _tmp75_ = FALSE;
	GXmlDomNode* _tmp76_ = NULL;
	gchar* _tmp77_ = NULL;
	gchar* _tmp78_ = NULL;
	gchar* _tmp79_ = NULL;
	gboolean _tmp80_ = FALSE;
	gboolean _tmp87_ = FALSE;
	GXmlDomNode* _tmp88_ = NULL;
	gchar* _tmp89_ = NULL;
	gchar* _tmp90_ = NULL;
	gchar* _tmp91_ = NULL;
	gboolean _tmp92_ = FALSE;
	gboolean _tmp111_ = FALSE;
	GXmlDomNode* _tmp112_ = NULL;
	gchar* _tmp113_ = NULL;
	gchar* _tmp114_ = NULL;
	gchar* _tmp115_ = NULL;
	gboolean _tmp116_ = FALSE;
	gboolean _tmp188_ = FALSE;
	GXmlDomNode* _tmp189_ = NULL;
	gchar* _tmp190_ = NULL;
	gchar* _tmp191_ = NULL;
	gchar* _tmp192_ = NULL;
	gboolean _tmp193_ = FALSE;
	gchar* p = NULL;
	gchar* _tmp245_ = NULL;
	gboolean _tmp246_ = FALSE;
	GXmlDomNode* _tmp247_ = NULL;
	gchar* _tmp248_ = NULL;
	gchar* _tmp249_ = NULL;
	gchar* _tmp250_ = NULL;
	gboolean _tmp251_ = FALSE;
	const gchar* _tmp261_ = NULL;
	GXmlDomNode* _tmp262_ = NULL;
	gchar* _tmp263_ = NULL;
	gchar* _tmp264_ = NULL;
	gchar* _tmp265_ = NULL;
	gchar* _tmp266_ = NULL;
	gchar* _tmp267_ = NULL;
	GXmlDomNode* _tmp268_ = NULL;
	gchar* _tmp269_ = NULL;
	gchar* _tmp270_ = NULL;
	gchar* _tmp271_ = NULL;
	GXmlGomAttr* attr = NULL;
	GXmlGomElement* _tmp272_ = NULL;
	GXmlDomNode* _tmp273_ = NULL;
	gchar* _tmp274_ = NULL;
	gchar* _tmp275_ = NULL;
	gchar* _tmp276_ = NULL;
	GXmlDomNode* _tmp277_ = NULL;
	gchar* _tmp278_ = NULL;
	gchar* _tmp279_ = NULL;
	gchar* _tmp280_ = NULL;
	GXmlDomNode* _tmp281_ = NULL;
	gchar* _tmp282_ = NULL;
	gchar* _tmp283_ = NULL;
	gchar* _tmp284_ = NULL;
	GXmlDomNode* _tmp285_ = NULL;
	gchar* _tmp286_ = NULL;
	gchar* _tmp287_ = NULL;
	gchar* _tmp288_ = NULL;
	GXmlGomAttr* _tmp289_ = NULL;
	GXmlGomAttr* _tmp290_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = node;
	_tmp2_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp1_) : NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strcmp0 (_tmp4_, "") == 0;
	_g_free0 (_tmp4_);
	if (_tmp5_) {
		_tmp0_ = TRUE;
	} else {
		GXmlDomNode* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
		_tmp6_ = node;
		_tmp7_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp6_) : NULL);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = string_contains (_tmp9_, ":");
		_tmp0_ = _tmp10_;
		_g_free0 (_tmp9_);
	}
	if (_tmp0_) {
		const gchar* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		GError* _tmp17_ = NULL;
		_tmp11_ = _ ("Invalid attribute name: %s");
		_tmp12_ = node;
		_tmp13_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp12_) : NULL);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_CHARACTER_ERROR, _tmp11_, _tmp15_);
		_tmp17_ = _tmp16_;
		_g_free0 (_tmp15_);
		_inner_error_ = _tmp17_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp18_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ATTR)) {
		const gchar* _tmp19_ = NULL;
		GError* _tmp20_ = NULL;
		_tmp19_ = _ ("Invalid node type. DomAttr was expected");
		_tmp20_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp19_);
		_inner_error_ = _tmp20_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp23_ = node;
	_tmp24_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp23_) : NULL);
	_tmp25_ = _tmp24_;
	_tmp26_ = _tmp25_;
	_tmp27_ = g_strcmp0 (_tmp26_, "xmlns") == 0;
	_g_free0 (_tmp26_);
	if (_tmp27_) {
		GXmlDomNode* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		_tmp28_ = node;
		_tmp29_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp28_) : NULL);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp22_ = g_strcmp0 (_tmp31_, "http://www.w3.org/2000/xmlns/") != 0;
		_g_free0 (_tmp31_);
	} else {
		_tmp22_ = FALSE;
	}
	if (_tmp22_) {
		GXmlDomNode* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		_tmp32_ = node;
		_tmp33_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp32_) : NULL);
		_tmp34_ = _tmp33_;
		_tmp35_ = _tmp34_;
		_tmp21_ = g_strcmp0 (_tmp35_, "http://www.w3.org/2000/xmlns") != 0;
		_g_free0 (_tmp35_);
	} else {
		_tmp21_ = FALSE;
	}
	if (_tmp21_) {
		const gchar* _tmp36_ = NULL;
		GError* _tmp37_ = NULL;
		_tmp36_ = _ ("Namespace attributes prefixed with xmlns should use a namespace uri ht" \
"tp://www.w3.org/2000/xmlns");
		_tmp37_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp36_);
		_inner_error_ = _tmp37_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp39_ = node;
	_tmp40_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp39_) : NULL);
	_tmp41_ = _tmp40_;
	_tmp42_ = _tmp41_;
	_tmp43_ = g_strcmp0 (_tmp42_, "") == 0;
	_g_free0 (_tmp42_);
	if (_tmp43_) {
		_tmp38_ = TRUE;
	} else {
		gboolean _tmp44_ = FALSE;
		GXmlDomNode* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gboolean _tmp49_ = FALSE;
		_tmp45_ = node;
		_tmp46_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp45_) : NULL);
		_tmp47_ = _tmp46_;
		_tmp48_ = _tmp47_;
		_tmp49_ = _tmp48_ == NULL;
		_g_free0 (_tmp48_);
		if (_tmp49_) {
			GXmlDomNode* _tmp50_ = NULL;
			gchar* _tmp51_ = NULL;
			gchar* _tmp52_ = NULL;
			gchar* _tmp53_ = NULL;
			_tmp50_ = node;
			_tmp51_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp50_) : NULL);
			_tmp52_ = _tmp51_;
			_tmp53_ = _tmp52_;
			_tmp44_ = g_strcmp0 (_tmp53_, "xmlns") != 0;
			_g_free0 (_tmp53_);
		} else {
			_tmp44_ = FALSE;
		}
		_tmp38_ = _tmp44_;
	}
	if (_tmp38_) {
		gchar* s = NULL;
		GXmlDomNode* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		GXmlDomNode* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gboolean _tmp61_ = FALSE;
		const gchar* _tmp72_ = NULL;
		const gchar* _tmp73_ = NULL;
		GError* _tmp74_ = NULL;
		_tmp54_ = node;
		_tmp55_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp54_) : NULL);
		_tmp56_ = _tmp55_;
		s = _tmp56_;
		_tmp57_ = node;
		_tmp58_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp57_) : NULL);
		_tmp59_ = _tmp58_;
		_tmp60_ = _tmp59_;
		_tmp61_ = _tmp60_ != NULL;
		_g_free0 (_tmp60_);
		if (_tmp61_) {
			const gchar* _tmp62_ = NULL;
			GXmlDomNode* _tmp63_ = NULL;
			gchar* _tmp64_ = NULL;
			gchar* _tmp65_ = NULL;
			gchar* _tmp66_ = NULL;
			gchar* _tmp67_ = NULL;
			gchar* _tmp68_ = NULL;
			gchar* _tmp69_ = NULL;
			gchar* _tmp70_ = NULL;
			gchar* _tmp71_ = NULL;
			_tmp62_ = s;
			_tmp63_ = node;
			_tmp64_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp63_) : NULL);
			_tmp65_ = _tmp64_;
			_tmp66_ = _tmp65_;
			_tmp67_ = g_strconcat ("=<", _tmp66_, NULL);
			_tmp68_ = _tmp67_;
			_tmp69_ = g_strconcat (_tmp68_, ">", NULL);
			_tmp70_ = _tmp69_;
			_tmp71_ = g_strconcat (_tmp62_, _tmp70_, NULL);
			_g_free0 (s);
			s = _tmp71_;
			_g_free0 (_tmp70_);
			_g_free0 (_tmp68_);
			_g_free0 (_tmp66_);
		}
		_tmp72_ = _ ("Namespaced attributes should provide a non-null, non-empty prefix: %s");
		_tmp73_ = s;
		_tmp74_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp72_, _tmp73_);
		_inner_error_ = _tmp74_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (s);
		return NULL;
	}
	_tmp76_ = node;
	_tmp77_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp76_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp76_) : NULL);
	_tmp78_ = _tmp77_;
	_tmp79_ = _tmp78_;
	_tmp80_ = g_strcmp0 (_tmp79_, "xmlns") == 0;
	_g_free0 (_tmp79_);
	if (_tmp80_) {
		GXmlDomNode* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		_tmp81_ = node;
		_tmp82_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp81_) : NULL);
		_tmp83_ = _tmp82_;
		_tmp84_ = _tmp83_;
		_tmp75_ = g_strcmp0 (_tmp84_, "xmlns") == 0;
		_g_free0 (_tmp84_);
	} else {
		_tmp75_ = FALSE;
	}
	if (_tmp75_) {
		const gchar* _tmp85_ = NULL;
		GError* _tmp86_ = NULL;
		_tmp85_ = _ ("Invalid namespace attribute's name.");
		_tmp86_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp85_);
		_inner_error_ = _tmp86_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp88_ = node;
	_tmp89_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp88_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp88_) : NULL);
	_tmp90_ = _tmp89_;
	_tmp91_ = _tmp90_;
	_tmp92_ = g_strcmp0 (_tmp91_, "xmlns") == 0;
	_g_free0 (_tmp91_);
	if (_tmp92_) {
		_tmp87_ = TRUE;
	} else {
		GXmlDomNode* _tmp93_ = NULL;
		gchar* _tmp94_ = NULL;
		gchar* _tmp95_ = NULL;
		gchar* _tmp96_ = NULL;
		_tmp93_ = node;
		_tmp94_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp93_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp93_) : NULL);
		_tmp95_ = _tmp94_;
		_tmp96_ = _tmp95_;
		_tmp87_ = g_strcmp0 (_tmp96_, "xmlns") == 0;
		_g_free0 (_tmp96_);
	}
	if (_tmp87_) {
		gchar* asp = NULL;
		GXmlGomElement* _tmp97_ = NULL;
		GXmlDomNode* _tmp98_ = NULL;
		gchar* _tmp99_ = NULL;
		gchar* _tmp100_ = NULL;
		gchar* _tmp101_ = NULL;
		GXmlDomNode* _tmp102_ = NULL;
		gchar* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
		gchar* _tmp105_ = NULL;
		gchar* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		const gchar* _tmp108_ = NULL;
		_tmp97_ = self->_element;
		_tmp98_ = node;
		_tmp99_ = gxml_dom_node_get_node_value (_tmp98_);
		_tmp100_ = _tmp99_;
		_tmp101_ = _tmp100_;
		_tmp102_ = node;
		_tmp103_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp102_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp102_) : NULL);
		_tmp104_ = _tmp103_;
		_tmp105_ = _tmp104_;
		_tmp106_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp97_, _tmp101_, _tmp105_);
		_tmp107_ = _tmp106_;
		_g_free0 (_tmp105_);
		_g_free0 (_tmp101_);
		asp = _tmp107_;
		_tmp108_ = asp;
		if (_tmp108_ != NULL) {
			GXmlDomNode* _tmp109_ = NULL;
			GXmlDomNode* _tmp110_ = NULL;
			_tmp109_ = node;
			_tmp110_ = _g_object_ref0 (_tmp109_);
			result = _tmp110_;
			_g_free0 (asp);
			return result;
		}
		_g_free0 (asp);
	}
	_tmp112_ = node;
	_tmp113_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp112_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp112_) : NULL);
	_tmp114_ = _tmp113_;
	_tmp115_ = _tmp114_;
	_tmp116_ = g_strcmp0 (_tmp115_, "http://www.w3.org/2000/xmlns/") == 0;
	_g_free0 (_tmp115_);
	if (_tmp116_) {
		_tmp111_ = TRUE;
	} else {
		GXmlDomNode* _tmp117_ = NULL;
		gchar* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
		gchar* _tmp120_ = NULL;
		_tmp117_ = node;
		_tmp118_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp117_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp117_) : NULL);
		_tmp119_ = _tmp118_;
		_tmp120_ = _tmp119_;
		_tmp111_ = g_strcmp0 (_tmp120_, "http://www.w3.org/2000/xmlns") == 0;
		_g_free0 (_tmp120_);
	}
	if (_tmp111_) {
		GXmlDomNode* _tmp121_ = NULL;
		gchar* _tmp122_ = NULL;
		gchar* _tmp123_ = NULL;
		gchar* _tmp124_ = NULL;
		gboolean _tmp125_ = FALSE;
		GXmlDomNode* _tmp144_ = NULL;
		gchar* _tmp145_ = NULL;
		gchar* _tmp146_ = NULL;
		gchar* _tmp147_ = NULL;
		gboolean _tmp148_ = FALSE;
		_tmp121_ = node;
		_tmp122_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp121_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp121_) : NULL);
		_tmp123_ = _tmp122_;
		_tmp124_ = _tmp123_;
		_tmp125_ = g_strcmp0 (_tmp124_, "xmlns") == 0;
		_g_free0 (_tmp124_);
		if (_tmp125_) {
			gchar* ns_uri = NULL;
			GXmlGomElement* _tmp126_ = NULL;
			gchar* _tmp127_ = NULL;
			gboolean _tmp128_ = FALSE;
			const gchar* _tmp129_ = NULL;
			_tmp126_ = self->_element;
			_tmp127_ = gxml_gom_element_lookup_namespace_uri (_tmp126_, NULL);
			ns_uri = _tmp127_;
			_tmp129_ = ns_uri;
			if (_tmp129_ != NULL) {
				const gchar* _tmp130_ = NULL;
				GXmlDomNode* _tmp131_ = NULL;
				gchar* _tmp132_ = NULL;
				gchar* _tmp133_ = NULL;
				gchar* _tmp134_ = NULL;
				_tmp130_ = ns_uri;
				_tmp131_ = node;
				_tmp132_ = gxml_dom_node_get_node_value (_tmp131_);
				_tmp133_ = _tmp132_;
				_tmp134_ = _tmp133_;
				_tmp128_ = g_strcmp0 (_tmp130_, _tmp134_) != 0;
				_g_free0 (_tmp134_);
			} else {
				_tmp128_ = FALSE;
			}
			if (_tmp128_) {
				const gchar* _tmp135_ = NULL;
				GXmlDomNode* _tmp136_ = NULL;
				gchar* _tmp137_ = NULL;
				gchar* _tmp138_ = NULL;
				gchar* _tmp139_ = NULL;
				gchar* _tmp140_ = NULL;
				gchar* _tmp141_ = NULL;
				GError* _tmp142_ = NULL;
				GError* _tmp143_ = NULL;
				_tmp135_ = _ ("Redefinition of default namespace for %s");
				_tmp136_ = node;
				_tmp137_ = gxml_dom_node_get_node_value (_tmp136_);
				_tmp138_ = _tmp137_;
				_tmp139_ = _tmp138_;
				_tmp140_ = g_strdup_printf (_tmp135_, _tmp139_);
				_tmp141_ = _tmp140_;
				_tmp142_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp141_);
				_tmp143_ = _tmp142_;
				_g_free0 (_tmp141_);
				_g_free0 (_tmp139_);
				_inner_error_ = _tmp143_;
				g_propagate_error (error, _inner_error_);
				_g_free0 (ns_uri);
				return NULL;
			}
			_g_free0 (ns_uri);
		}
		_tmp144_ = node;
		_tmp145_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp144_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp144_) : NULL);
		_tmp146_ = _tmp145_;
		_tmp147_ = _tmp146_;
		_tmp148_ = g_strcmp0 (_tmp147_, "xmlns") == 0;
		_g_free0 (_tmp147_);
		if (_tmp148_) {
			gchar* nsprefix = NULL;
			GXmlGomElement* _tmp149_ = NULL;
			GXmlDomNode* _tmp150_ = NULL;
			gchar* _tmp151_ = NULL;
			gchar* _tmp152_ = NULL;
			gchar* _tmp153_ = NULL;
			gchar* _tmp154_ = NULL;
			gchar* _tmp155_ = NULL;
			gchar* nsuri = NULL;
			GXmlGomElement* _tmp156_ = NULL;
			GXmlDomNode* _tmp157_ = NULL;
			gchar* _tmp158_ = NULL;
			gchar* _tmp159_ = NULL;
			gchar* _tmp160_ = NULL;
			gchar* _tmp161_ = NULL;
			gchar* _tmp162_ = NULL;
			gboolean _tmp163_ = FALSE;
			gboolean _tmp164_ = FALSE;
			const gchar* _tmp165_ = NULL;
			_tmp149_ = self->_element;
			_tmp150_ = node;
			_tmp151_ = gxml_dom_node_get_node_value (_tmp150_);
			_tmp152_ = _tmp151_;
			_tmp153_ = _tmp152_;
			_tmp154_ = gxml_gom_element_lookup_prefix (_tmp149_, _tmp153_);
			_tmp155_ = _tmp154_;
			_g_free0 (_tmp153_);
			nsprefix = _tmp155_;
			_tmp156_ = self->_element;
			_tmp157_ = node;
			_tmp158_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp157_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp157_) : NULL);
			_tmp159_ = _tmp158_;
			_tmp160_ = _tmp159_;
			_tmp161_ = gxml_gom_element_lookup_namespace_uri (_tmp156_, _tmp160_);
			_tmp162_ = _tmp161_;
			_g_free0 (_tmp160_);
			nsuri = _tmp162_;
			_tmp165_ = nsprefix;
			if (_tmp165_ != NULL) {
				_tmp164_ = TRUE;
			} else {
				const gchar* _tmp166_ = NULL;
				_tmp166_ = nsuri;
				_tmp164_ = _tmp166_ != NULL;
			}
			if (_tmp164_) {
				gboolean _tmp167_ = FALSE;
				const gchar* _tmp168_ = NULL;
				GXmlDomNode* _tmp169_ = NULL;
				gchar* _tmp170_ = NULL;
				gchar* _tmp171_ = NULL;
				gchar* _tmp172_ = NULL;
				gboolean _tmp173_ = FALSE;
				_tmp168_ = nsprefix;
				_tmp169_ = node;
				_tmp170_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp169_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp169_) : NULL);
				_tmp171_ = _tmp170_;
				_tmp172_ = _tmp171_;
				_tmp173_ = g_strcmp0 (_tmp168_, _tmp172_) != 0;
				_g_free0 (_tmp172_);
				if (_tmp173_) {
					_tmp167_ = TRUE;
				} else {
					const gchar* _tmp174_ = NULL;
					GXmlDomNode* _tmp175_ = NULL;
					gchar* _tmp176_ = NULL;
					gchar* _tmp177_ = NULL;
					gchar* _tmp178_ = NULL;
					_tmp174_ = nsuri;
					_tmp175_ = node;
					_tmp176_ = gxml_dom_node_get_node_value (_tmp175_);
					_tmp177_ = _tmp176_;
					_tmp178_ = _tmp177_;
					_tmp167_ = g_strcmp0 (_tmp174_, _tmp178_) != 0;
					_g_free0 (_tmp178_);
				}
				_tmp163_ = _tmp167_;
			} else {
				_tmp163_ = FALSE;
			}
			if (_tmp163_) {
				const gchar* _tmp179_ = NULL;
				GXmlDomNode* _tmp180_ = NULL;
				gchar* _tmp181_ = NULL;
				gchar* _tmp182_ = NULL;
				gchar* _tmp183_ = NULL;
				gchar* _tmp184_ = NULL;
				gchar* _tmp185_ = NULL;
				GError* _tmp186_ = NULL;
				GError* _tmp187_ = NULL;
				_tmp179_ = _ ("Redefinition of namespace's prefix for %s");
				_tmp180_ = node;
				_tmp181_ = gxml_dom_node_get_node_value (_tmp180_);
				_tmp182_ = _tmp181_;
				_tmp183_ = _tmp182_;
				_tmp184_ = g_strdup_printf (_tmp179_, _tmp183_);
				_tmp185_ = _tmp184_;
				_tmp186_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp185_);
				_tmp187_ = _tmp186_;
				_g_free0 (_tmp185_);
				_g_free0 (_tmp183_);
				_inner_error_ = _tmp187_;
				g_propagate_error (error, _inner_error_);
				_g_free0 (nsuri);
				_g_free0 (nsprefix);
				return NULL;
			}
			_g_free0 (nsuri);
			_g_free0 (nsprefix);
		}
	}
	_tmp189_ = node;
	_tmp190_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp189_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp189_) : NULL);
	_tmp191_ = _tmp190_;
	_tmp192_ = _tmp191_;
	_tmp193_ = g_strcmp0 (_tmp192_, "http://www.w3.org/2000/xmlns/") != 0;
	_g_free0 (_tmp192_);
	if (_tmp193_) {
		GXmlDomNode* _tmp194_ = NULL;
		gchar* _tmp195_ = NULL;
		gchar* _tmp196_ = NULL;
		gchar* _tmp197_ = NULL;
		_tmp194_ = node;
		_tmp195_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp194_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp194_) : NULL);
		_tmp196_ = _tmp195_;
		_tmp197_ = _tmp196_;
		_tmp188_ = g_strcmp0 (_tmp197_, "http://www.w3.org/2000/xmlns") != 0;
		_g_free0 (_tmp197_);
	} else {
		_tmp188_ = FALSE;
	}
	if (_tmp188_) {
		gchar* nsn = NULL;
		GXmlGomElement* _tmp198_ = NULL;
		GXmlDomNode* _tmp199_ = NULL;
		gchar* _tmp200_ = NULL;
		gchar* _tmp201_ = NULL;
		gchar* _tmp202_ = NULL;
		gchar* _tmp203_ = NULL;
		gchar* _tmp204_ = NULL;
		gchar* nspn = NULL;
		GXmlGomElement* _tmp205_ = NULL;
		const gchar* _tmp206_ = NULL;
		gchar* _tmp207_ = NULL;
		gboolean _tmp208_ = FALSE;
		const gchar* _tmp209_ = NULL;
		GXmlDomNode* _tmp210_ = NULL;
		gchar* _tmp211_ = NULL;
		gchar* _tmp212_ = NULL;
		gchar* _tmp213_ = NULL;
		gboolean _tmp214_ = FALSE;
		GXmlGomElement* _tmp222_ = NULL;
		GXmlDomNode* _tmp223_ = NULL;
		gchar* _tmp224_ = NULL;
		gchar* _tmp225_ = NULL;
		gchar* _tmp226_ = NULL;
		gchar* _tmp227_ = NULL;
		GXmlGomElement* _tmp228_ = NULL;
		const gchar* _tmp229_ = NULL;
		gchar* _tmp230_ = NULL;
		gboolean _tmp231_ = FALSE;
		const gchar* _tmp232_ = NULL;
		GXmlDomNode* _tmp233_ = NULL;
		gchar* _tmp234_ = NULL;
		gchar* _tmp235_ = NULL;
		gchar* _tmp236_ = NULL;
		gboolean _tmp237_ = FALSE;
		_tmp198_ = self->_element;
		_tmp199_ = node;
		_tmp200_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp199_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp199_) : NULL);
		_tmp201_ = _tmp200_;
		_tmp202_ = _tmp201_;
		_tmp203_ = gxml_gom_element_lookup_namespace_uri (_tmp198_, _tmp202_);
		_tmp204_ = _tmp203_;
		_g_free0 (_tmp202_);
		nsn = _tmp204_;
		_tmp205_ = self->_element;
		_tmp206_ = nsn;
		_tmp207_ = gxml_gom_element_lookup_prefix (_tmp205_, _tmp206_);
		nspn = _tmp207_;
		_tmp209_ = nspn;
		_tmp210_ = node;
		_tmp211_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp210_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp210_) : NULL);
		_tmp212_ = _tmp211_;
		_tmp213_ = _tmp212_;
		_tmp214_ = g_strcmp0 (_tmp209_, _tmp213_) != 0;
		_g_free0 (_tmp213_);
		if (_tmp214_) {
			const gchar* _tmp215_ = NULL;
			GXmlDomNode* _tmp216_ = NULL;
			gchar* _tmp217_ = NULL;
			gchar* _tmp218_ = NULL;
			gchar* _tmp219_ = NULL;
			_tmp215_ = nsn;
			_tmp216_ = node;
			_tmp217_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp216_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp216_) : NULL);
			_tmp218_ = _tmp217_;
			_tmp219_ = _tmp218_;
			_tmp208_ = g_strcmp0 (_tmp215_, _tmp219_) != 0;
			_g_free0 (_tmp219_);
		} else {
			_tmp208_ = FALSE;
		}
		if (_tmp208_) {
			const gchar* _tmp220_ = NULL;
			GError* _tmp221_ = NULL;
			_tmp220_ = _ ("Trying to add an attribute with an undefined namespace prefix");
			_tmp221_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp220_);
			_inner_error_ = _tmp221_;
			g_propagate_error (error, _inner_error_);
			_g_free0 (nspn);
			_g_free0 (nsn);
			return NULL;
		}
		_tmp222_ = self->_element;
		_tmp223_ = node;
		_tmp224_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp223_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp223_) : NULL);
		_tmp225_ = _tmp224_;
		_tmp226_ = _tmp225_;
		_tmp227_ = gxml_gom_element_lookup_prefix (_tmp222_, _tmp226_);
		_g_free0 (nspn);
		nspn = _tmp227_;
		_g_free0 (_tmp226_);
		_tmp228_ = self->_element;
		_tmp229_ = nspn;
		_tmp230_ = gxml_gom_element_lookup_namespace_uri (_tmp228_, _tmp229_);
		_g_free0 (nsn);
		nsn = _tmp230_;
		_tmp232_ = nspn;
		_tmp233_ = node;
		_tmp234_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp233_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp233_) : NULL);
		_tmp235_ = _tmp234_;
		_tmp236_ = _tmp235_;
		_tmp237_ = g_strcmp0 (_tmp232_, _tmp236_) != 0;
		_g_free0 (_tmp236_);
		if (_tmp237_) {
			const gchar* _tmp238_ = NULL;
			GXmlDomNode* _tmp239_ = NULL;
			gchar* _tmp240_ = NULL;
			gchar* _tmp241_ = NULL;
			gchar* _tmp242_ = NULL;
			_tmp238_ = nsn;
			_tmp239_ = node;
			_tmp240_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp239_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp239_) : NULL);
			_tmp241_ = _tmp240_;
			_tmp242_ = _tmp241_;
			_tmp231_ = g_strcmp0 (_tmp238_, _tmp242_) != 0;
			_g_free0 (_tmp242_);
		} else {
			_tmp231_ = FALSE;
		}
		if (_tmp231_) {
			const gchar* _tmp243_ = NULL;
			GError* _tmp244_ = NULL;
			_tmp243_ = _ ("Trying to add an attribute with a non found namespace URI");
			_tmp244_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp243_);
			_inner_error_ = _tmp244_;
			g_propagate_error (error, _inner_error_);
			_g_free0 (nspn);
			_g_free0 (nsn);
			return NULL;
		}
		_g_free0 (nspn);
		_g_free0 (nsn);
	}
	_tmp245_ = g_strdup ("");
	p = _tmp245_;
	_tmp247_ = node;
	_tmp248_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp247_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp247_) : NULL);
	_tmp249_ = _tmp248_;
	_tmp250_ = _tmp249_;
	_tmp251_ = _tmp250_ != NULL;
	_g_free0 (_tmp250_);
	if (_tmp251_) {
		GXmlDomNode* _tmp252_ = NULL;
		gchar* _tmp253_ = NULL;
		gchar* _tmp254_ = NULL;
		gchar* _tmp255_ = NULL;
		_tmp252_ = node;
		_tmp253_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp252_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp252_) : NULL);
		_tmp254_ = _tmp253_;
		_tmp255_ = _tmp254_;
		_tmp246_ = g_strcmp0 (_tmp255_, "") != 0;
		_g_free0 (_tmp255_);
	} else {
		_tmp246_ = FALSE;
	}
	if (_tmp246_) {
		GXmlDomNode* _tmp256_ = NULL;
		gchar* _tmp257_ = NULL;
		gchar* _tmp258_ = NULL;
		gchar* _tmp259_ = NULL;
		gchar* _tmp260_ = NULL;
		_tmp256_ = node;
		_tmp257_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp256_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp256_) : NULL);
		_tmp258_ = _tmp257_;
		_tmp259_ = _tmp258_;
		_tmp260_ = g_strconcat (_tmp259_, ":", NULL);
		_g_free0 (p);
		p = _tmp260_;
		_g_free0 (_tmp259_);
	}
	_tmp261_ = p;
	_tmp262_ = node;
	_tmp263_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp262_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp262_) : NULL);
	_tmp264_ = _tmp263_;
	_tmp265_ = _tmp264_;
	_tmp266_ = g_strconcat (_tmp261_, _tmp265_, NULL);
	_tmp267_ = _tmp266_;
	_tmp268_ = node;
	_tmp269_ = gxml_dom_node_get_node_value (_tmp268_);
	_tmp270_ = _tmp269_;
	_tmp271_ = _tmp270_;
	gee_abstract_map_set ((GeeAbstractMap*) self, _tmp267_, _tmp271_);
	_g_free0 (_tmp271_);
	_g_free0 (_tmp267_);
	_g_free0 (_tmp265_);
	_tmp272_ = self->_element;
	_tmp273_ = node;
	_tmp274_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp273_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp273_) : NULL);
	_tmp275_ = _tmp274_;
	_tmp276_ = _tmp275_;
	_tmp277_ = node;
	_tmp278_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp277_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp277_) : NULL);
	_tmp279_ = _tmp278_;
	_tmp280_ = _tmp279_;
	_tmp281_ = node;
	_tmp282_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp281_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp281_) : NULL);
	_tmp283_ = _tmp282_;
	_tmp284_ = _tmp283_;
	_tmp285_ = node;
	_tmp286_ = gxml_dom_node_get_node_value (_tmp285_);
	_tmp287_ = _tmp286_;
	_tmp288_ = _tmp287_;
	_tmp289_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) _tmp272_, _tmp276_, _tmp280_, _tmp284_, _tmp288_);
	_tmp290_ = _tmp289_;
	_g_free0 (_tmp288_);
	_g_free0 (_tmp284_);
	_g_free0 (_tmp280_);
	_g_free0 (_tmp276_);
	attr = _tmp290_;
	result = (GXmlDomNode*) attr;
	_g_free0 (p);
	return result;
}


static gint gxml_gom_element_attributes_real_get_length (GXmlDomNamedNodeMap* base) {
	gint result;
	GXmlGomElementAttributes* self;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	self = (GXmlGomElementAttributes*) base;
	_tmp0_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static void gxml_gom_element_attributes_class_init (GXmlGomElementAttributesClass * klass) {
	gxml_gom_element_attributes_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_element_attributes_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_element_attributes_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH, g_param_spec_int ("length", "length", "length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gom_element_attributes_gxml_dom_named_node_map_interface_init (GXmlDomNamedNodeMapIface * iface) {
	gxml_gom_element_attributes_gxml_dom_named_node_map_parent_iface = g_type_interface_peek_parent (iface);
	iface->item = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, gint)) gxml_gom_element_attributes_real_item;
	iface->get_named_item = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, const gchar*)) gxml_gom_element_attributes_real_get_named_item;
	iface->set_named_item = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, GXmlDomNode*, GError**)) gxml_gom_element_attributes_real_set_named_item;
	iface->remove_named_item = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, const gchar*, GError**)) gxml_gom_element_attributes_real_remove_named_item;
	iface->remove_named_item_ns = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, const gchar*, const gchar*, GError**)) gxml_gom_element_attributes_real_remove_named_item_ns;
	iface->get_named_item_ns = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, const gchar*, const gchar*, GError**)) gxml_gom_element_attributes_real_get_named_item_ns;
	iface->set_named_item_ns = (GXmlDomNode* (*)(GXmlDomNamedNodeMap*, GXmlDomNode*, GError**)) gxml_gom_element_attributes_real_set_named_item_ns;
	iface->get_length = gxml_gom_element_attributes_real_get_length;
}


static void gxml_gom_element_attributes_instance_init (GXmlGomElementAttributes * self) {
}


static void gxml_gom_element_attributes_finalize (GObject* obj) {
	GXmlGomElementAttributes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributes);
	_g_object_unref0 (self->_element);
	G_OBJECT_CLASS (gxml_gom_element_attributes_parent_class)->finalize (obj);
}


/**
   * Holds attributes in current node, using attribute's name as key
   * and it's value as value. Appends namespace prefix to attribute's name as
   * key if a namespaced attribute.
   */
GType gxml_gom_element_attributes_get_type (void) {
	static volatile gsize gxml_gom_element_attributes_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_element_attributes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomElementAttributesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_element_attributes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomElementAttributes), 0, (GInstanceInitFunc) gxml_gom_element_attributes_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_named_node_map_info = { (GInterfaceInitFunc) gxml_gom_element_attributes_gxml_dom_named_node_map_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_element_attributes_type_id;
		gxml_gom_element_attributes_type_id = g_type_register_static (GEE_TYPE_HASH_MAP, "GXmlGomElementAttributes", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_element_attributes_type_id, GXML_TYPE_DOM_NAMED_NODE_MAP, &gxml_dom_named_node_map_info);
		g_once_init_leave (&gxml_gom_element_attributes_type_id__volatile, gxml_gom_element_attributes_type_id);
	}
	return gxml_gom_element_attributes_type_id__volatile;
}


static void _vala_gxml_gom_element_attributes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomElementAttributes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributes);
	switch (property_id) {
		case GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH:
		g_value_set_int (value, gxml_dom_named_node_map_get_length ((GXmlDomNamedNodeMap*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void gxml_gom_element_class_init (GXmlGomElementClass * klass) {
	gxml_gom_element_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_element_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_element_set_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_gom_element_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_element_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING, g_param_spec_object ("previous-element-sibling", "previous-element-sibling", "previous-element-sibling", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING, g_param_spec_object ("next-element-sibling", "next-element-sibling", "next-element-sibling", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CHILDREN, g_param_spec_object ("children", "children", "children", GXML_TYPE_DOM_HTML_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD, g_param_spec_object ("first-element-child", "first-element-child", "first-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD, g_param_spec_object ("last-element-child", "last-element-child", "last-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT, g_param_spec_int ("child-element-count", "child-element-count", "child-element-count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_NAMESPACE_URI, g_param_spec_string ("namespace-uri", "namespace-uri", "namespace-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_PREFIX, g_param_spec_string ("prefix", "prefix", "prefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	/**
	   * Derived classes should define it at construction time, using
	   * {@link GomNode._local_name} field. This is the node's name.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_LOCAL_NAME, g_param_spec_string ("local-name", "local-name", "local-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_TAG_NAME, g_param_spec_string ("tag-name", "tag-name", "tag-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	/**
	   * An attribute called 'id'.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_ID, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * An attribute called 'class'.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CLASS_NAME, g_param_spec_string ("class-name", "class-name", "class-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * A list of values of all attributes called 'class'.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CLASS_LIST, g_param_spec_object ("class-list", "class-list", "class-list", GXML_TYPE_DOM_TOKEN_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_ATTRIBUTES, g_param_spec_object ("attributes", "attributes", "attributes", GXML_TYPE_DOM_NAMED_NODE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gom_element_gxml_dom_child_node_interface_init (GXmlDomChildNodeIface * iface) {
	gxml_gom_element_gxml_dom_child_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->remove = (void (*)(GXmlDomChildNode*)) gxml_gom_element_real_remove;
}


static void gxml_gom_element_gxml_dom_non_document_type_child_node_interface_init (GXmlDomNonDocumentTypeChildNodeIface * iface) {
	gxml_gom_element_gxml_dom_non_document_type_child_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_previous_element_sibling = gxml_gom_element_real_get_previous_element_sibling;
	iface->get_next_element_sibling = gxml_gom_element_real_get_next_element_sibling;
}


static void gxml_gom_element_gxml_dom_parent_node_interface_init (GXmlDomParentNodeIface * iface) {
	gxml_gom_element_gxml_dom_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->query_selector = (GXmlDomElement* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_element_real_query_selector;
	iface->query_selector_all = (GXmlDomNodeList* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_element_real_query_selector_all;
	iface->get_children = gxml_gom_element_real_get_children;
	iface->get_first_element_child = gxml_gom_element_real_get_first_element_child;
	iface->get_last_element_child = gxml_gom_element_real_get_last_element_child;
	iface->get_child_element_count = gxml_gom_element_real_get_child_element_count;
}


static void gxml_gom_element_gxml_dom_element_interface_init (GXmlDomElementIface * iface) {
	gxml_gom_element_gxml_dom_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_attribute = (gchar* (*)(GXmlDomElement*, const gchar*)) gxml_gom_element_real_get_attribute;
	iface->get_attribute_ns = (gchar* (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_get_attribute_ns;
	iface->set_attribute = (void (*)(GXmlDomElement*, const gchar*, const gchar*, GError**)) gxml_gom_element_real_set_attribute;
	iface->set_attribute_ns = (void (*)(GXmlDomElement*, const gchar*, const gchar*, const gchar*, GError**)) gxml_gom_element_real_set_attribute_ns;
	iface->remove_attribute = (void (*)(GXmlDomElement*, const gchar*)) gxml_gom_element_real_remove_attribute;
	iface->remove_attribute_ns = (void (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_remove_attribute_ns;
	iface->has_attribute = (gboolean (*)(GXmlDomElement*, const gchar*)) gxml_gom_element_real_has_attribute;
	iface->has_attribute_ns = (gboolean (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_has_attribute_ns;
	iface->get_elements_by_tag_name = (GXmlDomHTMLCollection* (*)(GXmlDomElement*, const gchar*)) gxml_gom_element_real_get_elements_by_tag_name;
	iface->get_elements_by_tag_name_ns = (GXmlDomHTMLCollection* (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_get_elements_by_tag_name_ns;
	iface->get_elements_by_class_name = (GXmlDomHTMLCollection* (*)(GXmlDomElement*, const gchar*)) gxml_gom_element_real_get_elements_by_class_name;
	iface->get_namespace_uri = gxml_gom_element_real_get_namespace_uri;
	iface->get_prefix = gxml_gom_element_real_get_prefix;
	iface->get_local_name = gxml_gom_element_real_get_local_name;
	iface->get_tag_name = gxml_gom_element_real_get_tag_name;
	iface->get_id = gxml_gom_element_real_get_id;
	iface->set_id = gxml_gom_element_real_set_id;
	iface->get_class_name = gxml_gom_element_real_get_class_name;
	iface->set_class_name = gxml_gom_element_real_set_class_name;
	iface->get_class_list = gxml_gom_element_real_get_class_list;
	iface->get_attributes = gxml_gom_element_real_get_attributes;
}


static void gxml_gom_element_gxml_gom_object_interface_init (GXmlGomObjectIface * iface) {
	gxml_gom_element_gxml_gom_object_parent_iface = g_type_interface_peek_parent (iface);
}


static void gxml_gom_element_instance_init (GXmlGomElement * self) {
	self->_namespace_uri = NULL;
}


static void gxml_gom_element_finalize (GObject* obj) {
	GXmlGomElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	_g_object_unref0 (self->_attributes);
	_g_free0 (self->_namespace_uri);
	G_OBJECT_CLASS (gxml_gom_element_parent_class)->finalize (obj);
}


/**
 * A GXml Object Model (GOM) implementation of {@link GomElement}.It can be used
 * transparently as {@link DomElement} in a XML tree.
 */
GType gxml_gom_element_get_type (void) {
	static volatile gsize gxml_gom_element_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_element_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_element_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomElement), 0, (GInstanceInitFunc) gxml_gom_element_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_child_node_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_child_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_non_document_type_child_node_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_non_document_type_child_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_parent_node_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_element_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_gom_object_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_gom_object_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_element_type_id;
		gxml_gom_element_type_id = g_type_register_static (GXML_TYPE_GOM_NODE, "GXmlGomElement", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_CHILD_NODE, &gxml_dom_child_node_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, &gxml_dom_non_document_type_child_node_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_PARENT_NODE, &gxml_dom_parent_node_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_ELEMENT, &gxml_dom_element_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_GOM_OBJECT, &gxml_gom_object_info);
		g_once_init_leave (&gxml_gom_element_type_id__volatile, gxml_gom_element_type_id);
	}
	return gxml_gom_element_type_id__volatile;
}


static void _vala_gxml_gom_element_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	switch (property_id) {
		case GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING:
		g_value_set_object (value, gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) self));
		break;
		case GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING:
		g_value_set_object (value, gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) self));
		break;
		case GXML_GOM_ELEMENT_CHILDREN:
		g_value_take_object (value, gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_first_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_last_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT:
		g_value_set_int (value, gxml_dom_parent_node_get_child_element_count ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_NAMESPACE_URI:
		g_value_take_string (value, gxml_dom_element_get_namespace_uri ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_PREFIX:
		g_value_take_string (value, gxml_dom_element_get_prefix ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_LOCAL_NAME:
		g_value_take_string (value, gxml_dom_element_get_local_name ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_TAG_NAME:
		g_value_take_string (value, gxml_dom_element_get_tag_name ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_ID:
		g_value_take_string (value, gxml_dom_element_get_id ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_CLASS_NAME:
		g_value_take_string (value, gxml_dom_element_get_class_name ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_CLASS_LIST:
		g_value_take_object (value, gxml_dom_element_get_class_list ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_ATTRIBUTES:
		g_value_take_object (value, gxml_dom_element_get_attributes ((GXmlDomElement*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_element_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	switch (property_id) {
		case GXML_GOM_ELEMENT_ID:
		gxml_dom_element_set_id ((GXmlDomElement*) self, g_value_get_string (value));
		break;
		case GXML_GOM_ELEMENT_CLASS_NAME:
		gxml_dom_element_set_class_name ((GXmlDomElement*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



